@@ -92,22 +92,22 @@ public:
   : m_plugin(plugin), m_id(id), m_defaultArea(defaultArea)
   {}
 
-  virtual QWidget* create(QWidget *parent = 0) override
+  QWidget* create(QWidget *parent = 0) override
   {
     return new T(m_plugin, parent);
   }
 
-  virtual QString id() const override
+  QString id() const override
   {
     return m_id;
   }
 
-  virtual Qt::DockWidgetArea defaultPosition() override
+  Qt::DockWidgetArea defaultPosition() override
   {
     return m_defaultArea;
   }
 
-  virtual void viewCreated(Sublime::View* view) override
+  void viewCreated(Sublime::View* view) override
   {
       if (view->widget()->metaObject()->indexOfSignal(QMetaObject::normalizedSignature("requestRaise()")) != -1)
           QObject::connect(view->widget(), SIGNAL(requestRaise()), view, SLOT(requestRaise()));
@@ -115,7 +115,7 @@ public:
 
   /* At present, some debugger widgets (e.g. breakpoint) contain actions so that shortcuts
      work, but they don't need any toolbar.  So, suppress toolbar action.  */
-  virtual QList<QAction*> toolBarActions( QWidget* viewWidget ) const override
+  QList<QAction*> toolBarActions( QWidget* viewWidget ) const override
   {
       Q_UNUSED(viewWidget);
       return QList<QAction*>();
