@@ -70,15 +70,17 @@ class DebugSession : public KDevelop::IDebugSession
     Q_OBJECT
 public:
     DebugSession();
-    ~DebugSession();
+    ~DebugSession() override;
 
-    virtual DebuggerState state() const override;
+    DebuggerState state() const override;
 
-    virtual bool restartAvaliable() const override;
+    bool restartAvaliable() const override;
 
-    virtual BreakpointController* breakpointController() const override;
-    virtual KDevelop::IVariableController* variableController() const override;
-    virtual KDevelop::IFrameStackModel* frameStackModel() const override;
+    BreakpointController* breakpointController() const override;
+    KDevelop::IVariableController* variableController() const override;
+    KDevelop::IFrameStackModel* frameStackModel() const override;
+
+    bool hasCrashed() const;
 
     using IDebugSession::event;
 Q_SIGNALS:
@@ -93,17 +95,17 @@ public Q_SLOTS:
      * Start the debugger, and execute the program specified by \a run.
      */
     bool startProgram(KDevelop::ILaunchConfiguration* run, IExecutePlugin* execute);
-    virtual void restartDebugger() override;
-    virtual void stopDebugger() override;
-    virtual void interruptDebugger() override;
-    virtual void run() override;
-    virtual void runToCursor() override;
-    virtual void jumpToCursor() override;
-    virtual void stepOver() override;
-    virtual void stepIntoInstruction() override;
-    virtual void stepInto() override;
-    virtual void stepOverInstruction() override;
-    virtual void stepOut() override;
+    void restartDebugger() override;
+    void stopDebugger() override;
+    void interruptDebugger() override;
+    void run() override;
+    void runToCursor() override;
+    void jumpToCursor() override;
+    void stepOver() override;
+    void stepIntoInstruction() override;
+    void stepInto() override;
+    void stepOverInstruction() override;
+    void stepOut() override;
 
     /**
      * Start the debugger and examine the core file given by \a coreFile.
@@ -143,7 +145,7 @@ public:
     /**
      * Run currently executing program to the given \a address
      */
-    void runUntil(QString& address);
+    void runUntil(const QString& address);
     /**
      * Move the execution point of the currently executing program to the given \a url and \a line.
      */
@@ -153,7 +155,7 @@ public:
      * Move the execution point of the currently executing program to the given \a address.
      *Note: It can be really very dangerous, so use jumpTo instead.
      */
-    void jumpToMemoryAddress(QString& address);
+    void jumpToMemoryAddress(const QString& address);
 
     /** Adds a command to the end of queue of commands to be executed
         by gdb. The command will be actually sent to gdb only when
@@ -288,11 +290,12 @@ private:
 
     /**When program stops and all commands from queue are executed and this variable is true, program state shown to the user is updated.*/
     bool state_reload_needed;
-
-    QTime commandExecutionTime;
-
     /**True if program has stopped and all stuff like breakpoints is being updated.*/
     bool stateReloadInProgress_;
+    /**True if process crashed*/
+    bool m_hasCrashed;
+
+    QTime commandExecutionTime;
 
     ///Exit code of the last inferior(in format: exit normally, with code "number" e.t.c)
     QString m_inferiorExitCode;
