@@ -60,7 +60,7 @@ GDBOutputWidget::GDBOutputWidget(CppDebuggerPlugin* plugin, QWidget *parent) :
     showInternalCommands_(false),
     maxLines_(5000)
 {
-    setWindowIcon(QIcon::fromTheme("dialog-scripts"));
+    setWindowIcon(QIcon::fromTheme("dialog-scripts", windowIcon()));
     setWindowTitle(i18n("GDB Output"));
     setWhatsThis(i18n("<b>GDB output</b><p>"
                     "Shows all gdb commands being executed. "
@@ -199,7 +199,7 @@ namespace {
 void GDBOutputWidget::newStdoutLine(const QString& line,
                                     bool internal)
 {
-    QString s = html_escape(line);
+    QString s = line.toHtmlEscaped();
     if (s.startsWith("(gdb)"))
     {
         s = colorify(s, gdbColor_);
@@ -273,7 +273,7 @@ void GDBOutputWidget::setShowInternalCommands(bool show)
 
 void GDBOutputWidget::slotReceivedStderr(const char* line)
 {
-    QString colored = colorify(html_escape(line), errorColor_);
+    QString colored = colorify(QString::fromLatin1(line).toHtmlEscaped(), errorColor_);
     // Errors are shown inside user commands too.
     allCommands_.append(colored);
     trimList(allCommands_, maxLines_);
@@ -362,14 +362,6 @@ void GDBOutputWidget::focusInEvent(QFocusEvent */*e*/)
     m_userGDBCmdEditor->setFocus();
 }
 
-QString GDBOutputWidget::html_escape(const QString& s)
-{
-    QString r(s);
-    r.replace('<', "&lt;");
-    r.replace('>', "&gt;");
-    return r;
-}
-
 void GDBOutputWidget::savePartialProjectSession()
 {
     KConfigGroup config(KSharedConfig::openConfig(), "GDB Debugger");
@@ -412,11 +404,11 @@ void GDBOutputWidget::copyAll()
 {
     /* See comments for allCommandRaw_ for explanations of
        this complex logic, as opposed to calling text(). */
-    QStringList& raw = showInternalCommands_ ?
+    const QStringList& raw = showInternalCommands_ ?
         allCommandsRaw_ : userCommandsRaw_;
     QString text;
     for (int i = 0; i < raw.size(); ++i)
-        text += raw[i];
+        text += raw.at(i);
 
     // Make sure the text is pastable both with Ctrl-C and with
     // middle click.
