@@ -65,12 +65,13 @@
 #include <QProcess>
 #include <QTemporaryFile>
 
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+
+#include <QCoreApplication>
+#include <QStandardPaths>
 
 #include "stty.h"
+#include "debug.h"
 
 #define PTY_FILENO 3
 #define BASE_CHOWN "konsole_grantpty"
@@ -94,7 +95,7 @@ static int chownpty(int fd, int grant)
         if (fd != PTY_FILENO && dup2(fd, PTY_FILENO) < 0)
             ::exit(1);
 
-        QString path = KStandardDirs::locate("exe", BASE_CHOWN);
+        QString path = QStandardPaths::findExecutable(BASE_CHOWN);
         execle(QFile::encodeName(path), BASE_CHOWN, grant?"--grant":"--revoke", (void *)0, NULL);
         ::exit(1); // should not be reached
     }
@@ -134,7 +135,7 @@ STTY::STTY(bool ext, const QString &termAppName)
         if (fout >= 0) {
             ttySlave = QString(tty_slave);
             out = new QSocketNotifier(fout, QSocketNotifier::Read, this);
-            connect( out, SIGNAL(activated(int)), this, SLOT(OutReceived(int)) );
+            connect( out, &QSocketNotifier::activated, this, &STTY::OutReceived );
         }
     }
 }
@@ -160,14 +161,19 @@ int STTY::findTTY()
 
 #ifdef __sgi__
     ptyfd = open("/dev/ptmx",O_RDWR);
-    if (ptyfd < 0) {
+#elif defined(Q_OS_MAC)
+    ptyfd = posix_openpt(O_RDWR);
+#endif
+#if defined(__sgi__) || defined(Q_OS_MAC)
+    if (ptyfd == -1) {
         perror("Can't open a pseudo teletype");
         return(-1);
+    } else if (ptyfd >= 0) {
+        strncpy(tty_slave, ptsname(ptyfd), 50);
+        grantpt(ptyfd);
+        unlockpt(ptyfd);
+        needGrantPty = false;
     }
-    strncpy(tty_slave, ptsname(ptyfd), 50);
-    grantpt(ptyfd);
-    unlockpt(ptyfd);
-    needGrantPty = false;
 #endif
 
     // first we try UNIX PTY's
@@ -287,7 +293,7 @@ bool STTY::findExternalTTY(const QString& termApp)
 {
     QString appName(termApp.isEmpty() ? QString("xterm") : termApp);
 
-    if (KStandardDirs::findExe(appName).isEmpty()) {
+    if (QStandardPaths::findExecutable(appName).isEmpty()) {
         m_lastError = i18n("%1 is incorrect terminal name", termApp);
         return false;
     }
@@ -322,7 +328,7 @@ bool STTY::findExternalTTY(const QString& termApp)
             QCoreApplication::processEvents(QEventLoop::AllEvents, 100);
             usleep(8000);
         } else {
-            kDebug() << "Received terminal output(tty)";
+            qCDebug(DEBUGGERGDB) << "Received terminal output(tty)";
             break;
         }
     }
@@ -339,4 +345,3 @@ bool STTY::findExternalTTY(const QString& termApp)
 }
 }
 // **************************************************************************
-#include "stty.moc"
