@@ -25,8 +25,7 @@
 #include <QTemporaryFile>
 #include <QHelpContentModel>
 
-#include <KDebug>
-#include <KStandardDirs>
+#include <QStandardPaths>
 
 #include <language/duchain/duchain.h>
 #include <language/duchain/declaration.h>
@@ -34,53 +33,50 @@
 #include <language/duchain/parsingenvironment.h>
 
 #include "qthelpdocumentation.h"
+#include "debug.h"
+
+using namespace KDevelop;
 
 QtHelpProviderAbstract::QtHelpProviderAbstract(QObject *parent, const QString &collectionFileName, const QVariantList &args)
     : QObject(parent)
-    , m_engine(KStandardDirs::locateLocal("appdata", collectionFileName, true))
+    , m_engine(QStandardPaths::writableLocation(QStandardPaths::DataLocation)+'/'+collectionFileName)
 {
     Q_UNUSED(args);
     if( !m_engine.setupData() ) {
-        kWarning() << "Couldn't setup QtHelp Collection file";
+        qWarning() << "Couldn't setup QtHelp Collection file";
     }
 }
 
-KSharedPtr< KDevelop::IDocumentation > QtHelpProviderAbstract::documentationForDeclaration(KDevelop::Declaration* dec) const
+IDocumentation::Ptr QtHelpProviderAbstract::documentationForDeclaration(Declaration* dec) const
 {
     QtHelpDocumentation::s_provider = const_cast<QtHelpProviderAbstract*>(this);
     if(dec) {
-        static const KDevelop::IndexedString qmlJs("QML/JS");
-        bool isQML = dec->topContext()->parsingEnvironmentFile()->language() == qmlJs;
-        QString id;
-        if(isQML) {
-            KDevelop::DUChainReadLocker lock;
-            QString ns;
-            bool isClass = dec->abstractType()->whichType() == KDevelop::AbstractType::TypeStructure;
-            if(!isClass && dec->context() && dec->context()->owner()) {
-                ns = dec->context()->owner()->abstractType()->toString();
-                ns += "::" + dec->identifier().toString();
-            } else {
-                ns = dec->abstractType()->toString();
-            }
+        static const IndexedString qmlJs("QML/JS");
+        bool isQML;
+        QStringList idParts;
 
-            id = "QML." + ns;
-        } else {
-            KDevelop::DUChainReadLocker lock;
-            KDevelop::QualifiedIdentifier qid = dec->qualifiedIdentifier();
-            lock.unlock();
-            id = qid.toStringList().join("::");
+        {
+            DUChainReadLocker lock;
+            isQML = dec->topContext()->parsingEnvironmentFile()->language() == qmlJs;
+            idParts = dec->qualifiedIdentifier().toStringList();
         }
 
-        if(!id.isEmpty()) {
+        QString id;
+        if(isQML && !idParts.isEmpty()) {
+            idParts.removeFirst(); // Skip the namespace (QtQuick2.0, etc)
+            id = QLatin1String("QML.");
+        }
+
+        if(!idParts.isEmpty()) {
+            id += idParts.join(QLatin1String("::"));
             QMap<QString, QUrl> links=m_engine.linksForIdentifier(id);
 
-            kDebug() << "doc_found" << id << links;
             if(!links.isEmpty())
-                return KDevelop::IDocumentation::Ptr(new QtHelpDocumentation(id, links));
+                return IDocumentation::Ptr(new QtHelpDocumentation(id, links));
         }
     }
 
-    return KSharedPtr<KDevelop::IDocumentation>();
+    return {};
 }
 
 QAbstractListModel* QtHelpProviderAbstract::indexModel() const
@@ -89,11 +85,11 @@ QAbstractListModel* QtHelpProviderAbstract::indexModel() const
     return m_engine.indexModel();
 }
 
-KSharedPtr< KDevelop::IDocumentation > QtHelpProviderAbstract::documentationForIndex(const QModelIndex& idx) const
+IDocumentation::Ptr QtHelpProviderAbstract::documentationForIndex(const QModelIndex& idx) const
 {
     QtHelpDocumentation::s_provider = const_cast<QtHelpProviderAbstract*>(this);
     QString name=idx.data(Qt::DisplayRole).toString();
-    return KSharedPtr<KDevelop::IDocumentation>(new QtHelpDocumentation(name, m_engine.indexModel()->linksForKeyword(name)));
+    return IDocumentation::Ptr(new QtHelpDocumentation(name, m_engine.indexModel()->linksForKeyword(name)));
 }
 
 void QtHelpProviderAbstract::jumpedTo(const QUrl& newUrl) const
@@ -101,14 +97,14 @@ void QtHelpProviderAbstract::jumpedTo(const QUrl& newUrl) const
     QtHelpDocumentation::s_provider = const_cast<QtHelpProviderAbstract*>(this);
     QMap<QString, QUrl> info;
     info.insert(newUrl.toString(), newUrl);
-    KSharedPtr<KDevelop::IDocumentation> doc(new QtHelpDocumentation(newUrl.toString(), info));
+    IDocumentation::Ptr doc(new QtHelpDocumentation(newUrl.toString(), info));
     emit addHistory(doc);
 }
 
-KSharedPtr<KDevelop::IDocumentation> QtHelpProviderAbstract::homePage() const
+IDocumentation::Ptr QtHelpProviderAbstract::homePage() const
 {
     QtHelpDocumentation::s_provider = const_cast<QtHelpProviderAbstract*>(this);
-    return KSharedPtr<KDevelop::IDocumentation>(new HomeDocumentation);
+    return IDocumentation::Ptr(new HomeDocumentation);
 }
 
 bool QtHelpProviderAbstract::isValid() const
