@@ -52,6 +52,7 @@
 #include "../duchain/navigationwidget.h"
 #include "../clangsettings/clangsettingsmanager.h"
 
+#include <functional>
 #include <memory>
 
 #include <KTextEditor/Document>
@@ -115,7 +116,7 @@ public:
     {
     }
 
-    virtual ~CompletionItem() = default;
+    ~CompletionItem() override = default;
 
     QVariant data(const QModelIndex& index, int role, const CodeCompletionModel* /*model*/) const override
     {
@@ -166,44 +167,6 @@ private:
     QString m_returnType;
 };
 
-class ImplementsItem : public CompletionItem<CompletionTreeItem>
-{
-public:
-    ImplementsItem(const FuncImplementInfo& item)
-        : CompletionItem<KDevelop::CompletionTreeItem>(
-              item.prototype,
-              i18n("Implement %1", item.isConstructor ? QStringLiteral("<constructor>") :
-                                   item.isDestructor ? QStringLiteral("<destructor>") : item.returnType)
-          )
-        , m_item(item)
-    {
-    }
-
-    QVariant data(const QModelIndex& index, int role, const CodeCompletionModel* model) const override
-    {
-        if (role == Qt::DecorationRole) {
-            if (index.column() == KTextEditor::CodeCompletionModel::Icon) {
-                static const QIcon icon = QIcon::fromTheme(QStringLiteral("CTsuppliers"));
-                return icon;
-            }
-        }
-        return CompletionItem<CompletionTreeItem>::data(index, role, model);
-    }
-
-    void execute(KTextEditor::View* view, const KTextEditor::Range& word) override
-    {
-        QString replacement = m_item.templatePrefix;
-        if (!m_item.isDestructor && !m_item.isConstructor) {
-            replacement += m_item.returnType + QLatin1Char(' ');
-        }
-        replacement += m_item.prototype + QLatin1String("\n{\n}\n");
-        view->document()->replaceText(word, replacement);
-    }
-
-private:
-    FuncImplementInfo m_item;
-};
-
 /**
  * Specialized completion item class for items which are represented by a Declaration
  */
@@ -240,7 +203,10 @@ public:
         }
 
         if(m_declaration->isFunctionDeclaration()) {
-            repl += QLatin1String("()");
+            auto doc = view->document();
+            if (doc->characterAt(word.end()) != QLatin1Char('(')) {
+                repl += QLatin1String("()");
+            }
             view->document()->replaceText(word, repl);
             auto f = m_declaration->type<FunctionType>();
             if (f && f->indexedArgumentsSize()) {
@@ -287,12 +253,48 @@ public:
         m_depth = depth;
     }
 
-private:
+protected:
     int m_matchQuality = 0;
     int m_depth = 0;
     QString m_replacement;
 };
 
+class ImplementsItem : public DeclarationItem
+{
+public:
+    static QString replacement(const FuncImplementInfo& info)
+    {
+        QString replacement = info.templatePrefix;
+        if (!info.isDestructor && !info.isConstructor) {
+            replacement += info.returnType + QLatin1Char(' ');
+        }
+        replacement += info.prototype + QLatin1String("\n{\n}\n");
+        return replacement;
+    }
+
+    ImplementsItem(const FuncImplementInfo& item)
+        : DeclarationItem(item.declaration.data(), item.prototype,
+            i18n("Implement %1", item.isConstructor ? QStringLiteral("<constructor>") :
+                                   item.isDestructor ? QStringLiteral("<destructor>") : item.returnType),
+            replacement(item)
+          )
+    {
+    }
+
+    QVariant data(const QModelIndex& index, int role, const CodeCompletionModel* model) const override
+    {
+        if (index.column() == CodeCompletionModel::Arguments) {
+            // our display string already contains the arguments
+            return {};
+        }
+        return DeclarationItem::data(index, role, model);
+    }
+
+    void execute(KTextEditor::View* view, const KTextEditor::Range& word) override
+    {
+        view->document()->replaceText(word, m_replacement);
+    }
+};
 
 class ArgumentHintItem : public DeclarationItem
 {
@@ -309,7 +311,7 @@ public:
         , m_arguments(arguments)
     {}
 
-     QVariant data(const QModelIndex& index, int role, const CodeCompletionModel* model) const override
+    QVariant data(const QModelIndex& index, int role, const CodeCompletionModel* model) const override
     {
         if (role == CodeCompletionModel::CustomHighlight && index.column() == CodeCompletionModel::Arguments && argumentHintDepth()) {
             QList<QVariant> highlighting;
@@ -508,6 +510,18 @@ Declaration* findDeclaration(const QualifiedIdentifier& qid, const DUContextPoin
 
     for (auto it = decl.iterator(); it; ++it) {
         auto declaration = it->declaration();
+        if (!declaration) {
+            // Mitigate problems such as: Cannot load a top-context from file "/home/kfunk/.cache/kdevduchain/kdevelop-{foo}/topcontexts/6085"
+            //  - the required language-support for handling ID 55 is probably not loaded
+            qCWarning(KDEV_CLANG) << "Detected an invalid declaration for" << qid;
+            continue;
+        }
+
+        const auto& file = declaration->topContext()->parsingEnvironmentFile();
+        if (!file || file->language() != ParseSession::languageString()) {
+            continue;
+        }
+
         if (declaration->kind() == Declaration::Instance && !declaration->isFunctionDeclaration()) {
             break;
         }
