@@ -62,7 +62,11 @@
 namespace {
 
 // TODO: this is ugly, can we find a better alternative?
-static bool s_jsonTestRun = false;
+bool jsonTestRun()
+{
+    static bool runningTest = qEnvironmentVariableIsSet("KDEV_CLANG_JSON_TEST_RUN");
+    return runningTest;
+}
 
 //BEGIN helpers
 /**
@@ -96,7 +100,7 @@ Identifier makeId(CXCursor cursor)
 
 QByteArray makeComment(CXComment comment)
 {
-    if (Q_UNLIKELY(s_jsonTestRun)) {
+    if (Q_UNLIKELY(jsonTestRun())) {
         auto kind = clang_Comment_getKind(comment);
         if (kind == CXComment_Text)
             return ClangString(clang_TextComment_getText(comment)).toByteArray();
@@ -255,6 +259,12 @@ struct CurrentContext
         DUChainWriteLocker lock;
         qDeleteAll(previousChildContexts);
         qDeleteAll(previousChildDeclarations);
+        if (resortChildContexts) {
+            context->resortChildContexts();
+        }
+        if (resortLocalDeclarations) {
+            context->resortLocalDeclarations();
+        }
     }
 
     DUContext* context;
@@ -262,6 +272,9 @@ struct CurrentContext
     QVector<DUContext*> previousChildContexts;
     // when updatig, this contains child declarations of the current parent context
     QVector<Declaration*> previousChildDeclarations;
+
+    bool resortChildContexts = false;
+    bool resortLocalDeclarations = false;
 };
 //END CurrentContext
 
@@ -355,8 +368,9 @@ struct Visitor
                 auto decl = dynamic_cast<DeclType*>(*it);
                 if (decl && decl->indexedIdentifier() == indexedId) {
                     decl->setRange(range);
+                    m_parentContext->resortLocalDeclarations = true;
                     setDeclData<CK>(cursor, decl);
-                    m_cursorToDeclarationCache[clang_hashCursor(cursor)] = decl;
+                    m_cursorToDeclarationCache[cursor] = decl;
                     m_parentContext->previousChildDeclarations.erase(it);
                     return decl;
                 }
@@ -365,7 +379,7 @@ struct Visitor
         }
         auto decl = new DeclType(range, nullptr);
         decl->setIdentifier(id);
-        m_cursorToDeclarationCache[clang_hashCursor(cursor)] = decl;
+        m_cursorToDeclarationCache[cursor] = decl;
         setDeclData<CK>(cursor, decl);
         {
             DUChainWriteLocker lock;
@@ -402,6 +416,7 @@ struct Visitor
                 auto ctx = *it;
                 if (ctx->type() == Type && ctx->indexedLocalScopeIdentifier() == indexedScopeId) {
                     ctx->setRange(range);
+                    m_parentContext->resortChildContexts = true;
                     m_parentContext->previousChildContexts.erase(it);
                     return ctx;
                 }
@@ -607,6 +622,17 @@ struct Visitor
         return makeType(clangType, cursor);
     }
 
+#if CINDEX_VERSION_MINOR >= 31
+    template<CXTypeKind TK, EnableIf<TK == CXType_Auto> = dummy>
+    AbstractType *createType(CXType type, CXCursor parent)
+    {
+        auto deducedType = clang_getCanonicalType(type);
+        bool isDeduced = deducedType.kind != CXType_Invalid && deducedType.kind != CXType_Auto;
+
+        return !isDeduced ? createDelayedType(type) : makeType(deducedType, parent);
+    }
+#endif
+
     /// @param declaration an optional declaration that will be associated with created type
     AbstractType* createClassTemplateSpecializationType(CXType type, const DeclarationPointer declaration = {})
     {
@@ -762,7 +788,7 @@ struct Visitor
     std::unordered_map<DUContext*, std::vector<CXCursor>> m_uses;
     /// At these location offsets (cf. @ref clang_getExpansionLocation) we encountered macro expansions
     QSet<unsigned int> m_macroExpansionLocations;
-    mutable QHash<unsigned int, DeclarationPointer> m_cursorToDeclarationCache;
+    mutable QHash<CXCursor, DeclarationPointer> m_cursorToDeclarationCache;
     CurrentContext *m_parentContext;
 
     const bool m_update;
@@ -924,8 +950,12 @@ void Visitor::setDeclData(CXCursor cursor, ClassMemberDeclaration *decl) const
         decl->setStatic(true);
     decl->setAccessPolicy(CursorKindTraits::kdevAccessPolicy(clang_getCXXAccessSpecifier(cursor)));
 
+#if CINDEX_VERSION_MINOR >= 31
+    decl->setMutable(clang_CXXField_isMutable(cursor));
+#endif
+
 #if CINDEX_VERSION_MINOR >= 30
-    if (!s_jsonTestRun) {
+    if (!jsonTestRun()) {
         auto offset = clang_Cursor_getOffsetOfField(cursor);
         if (offset >= 0) { // don't add this info to the json tests, it invalidates the comment structure
             auto type = clang_getCursorType(cursor);
@@ -966,7 +996,7 @@ void Visitor::setDeclData(CXCursor cursor, ClassDeclaration* decl) const
     if (clang_isCursorDefinition(cursor)) {
         decl->setDeclarationIsDefinition(true);
     }
-    if (!s_jsonTestRun) { // don't add this info to the json tests, it invalidates the comment structure
+    if (!jsonTestRun()) { // don't add this info to the json tests, it invalidates the comment structure
         auto type = clang_getCursorType(cursor);
         auto sizeOf = clang_Type_getSizeOf(type);
         auto alignOf = clang_Type_getAlignOf(type);
@@ -1135,8 +1165,7 @@ CXChildVisitResult Visitor::buildCXXBaseSpecifier(CXCursor cursor)
 
 DeclarationPointer Visitor::findDeclaration(CXCursor cursor) const
 {
-    const auto cursorHash = clang_hashCursor(cursor);
-    const auto it = m_cursorToDeclarationCache.constFind(cursorHash);
+    const auto it = m_cursorToDeclarationCache.constFind(cursor);
     if (it != m_cursorToDeclarationCache.constEnd()) {
         return *it;
     }
@@ -1144,7 +1173,7 @@ DeclarationPointer Visitor::findDeclaration(CXCursor cursor) const
     // fallback, and cache result
     auto decl = ClangHelpers::findDeclaration(cursor, m_includes);
 
-    m_cursorToDeclarationCache.insert(cursorHash, decl);
+    m_cursorToDeclarationCache.insert(cursor, decl);
     return decl;
 }
 
@@ -1203,6 +1232,9 @@ AbstractType *Visitor::makeType(CXType type, CXCursor parent)
     UseKind(CXType_ObjCClass);
     UseKind(CXType_ObjCSel);
     UseKind(CXType_NullPtr);
+#if CINDEX_VERSION_MINOR >= 31
+    UseKind(CXType_Auto);
+#endif
     case CXType_Invalid:
         return nullptr;
     default:
@@ -1273,13 +1305,24 @@ Visitor::Visitor(CXTranslationUnit tu, CXFile file,
     }
     for (const auto &contextUses : m_uses) {
         for (const auto &cursor : contextUses.second) {
-            auto referenced = clang_getCanonicalCursor(referencedCursor(cursor));
+            auto referenced = referencedCursor(cursor);
             if (clang_Cursor_isNull(referenced)) {
                 continue;
             }
+            // first, try the canonical referenced cursor
+            // this is important to get the correct function declaration e.g.
+            auto canonicalReferenced = clang_getCanonicalCursor(referenced);
+            auto used = findDeclaration(canonicalReferenced);
 
-            auto used = findDeclaration(referenced);
             if (!used) {
+                // if the above failed, try the non-canonicalized version as a fallback
+                // this is required for friend declarations that occur before
+                // the real declaration. there, the canonical cursor points to
+                // the friend declaration which is not what we are looking for
+                used = findDeclaration(referenced);
+            }
+
+            if (!used) { // as a last resort, try to resolve the forward declaration
                 DUChainReadLocker lock;
                 DeclarationPointer decl = ClangHelpers::findForwardDeclaration(clang_getCursorType(referenced), contextUses.first, referenced);
                 used = decl;
@@ -1394,9 +1437,4 @@ void visit(CXTranslationUnit tu, CXFile file, const IncludeFileContexts& include
     Visitor visitor(tu, file, includes, update);
 }
 
-void enableJSONTestRun()
-{
-    s_jsonTestRun = true;
-}
-
 }
\ No newline at end of file
