@@ -55,7 +55,11 @@ StaticAssistantsManager *staticAssistantsManager() { return Core::self()->langua
 
 void TestAssistants::initTestCase()
 {
-    QLoggingCategory::setFilterRules(QStringLiteral("*.debug=false\ndefault.debug=true\nkdevelop.plugins.clang.debug=true\n"));
+    QLoggingCategory::setFilterRules(QStringLiteral(R"(
+        *.debug=false
+        default.debug=true
+        kdevelop.plugins.clang.debug=true
+    )"));
     QVERIFY(qputenv("KDEV_DISABLE_PLUGINS", "kdevcppsupport"));
     AutoTestShell::init({QStringLiteral("kdevclangsupport")});
     TestCore::initialize();
@@ -231,8 +235,11 @@ void TestAssistants::testRenameAssistant_data()
     QTest::newRow("Prepend Text")
         << "int foo(int i)\n { i = 0; return i; }"
         << "i"
-        << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0,12,0,12), "u", "ui"))
-        << "int foo(int ui)\n { ui = 0; return ui; }";
+        << QList<StateChange>{
+            StateChange(Testbed::CppDoc, Range(0,12,0,12), "u", "ui"),
+            StateChange(Testbed::CppDoc, Range(0,13,0,13), "z", "uzi"),
+        }
+        << "int foo(int uzi)\n { uzi = 0; return uzi; }";
 
     QTest::newRow("Append Text")
         << "int foo(int i)\n { i = 0; return i; }"
@@ -340,6 +347,20 @@ void TestAssistants::testSignatureAssistant_data()
       << "class Foo {\nint bar(char a, char* b, int c = 10); \n};"
       << "int Foo::bar(char a, char* b, int c)\n{ a = c; b = new char; return a + *b; }";
 
+    QTest::newRow("prepend_arg_header")
+      << "class Foo { void bar(int i); };"
+      << "void Foo::bar(int i)\n{}"
+      << (QList<StateChange>() << StateChange(Testbed::HeaderDoc, Range(0, 21, 0, 21), "char c, ", SHOULD_ASSIST))
+      << "class Foo { void bar(char c, int i); };"
+      << "void Foo::bar(char c, int i)\n{}";
+
+    QTest::newRow("prepend_arg_cpp")
+      << "class Foo { void bar(int i); };"
+      << "void Foo::bar(int i)\n{}"
+      << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0, 14, 0, 14), "char c, ", SHOULD_ASSIST))
+      << "class Foo { void bar(char c, int i); };"
+      << "void Foo::bar(char c, int i)\n{}";
+
     QTest::newRow("change_default_parameter")
         << "class Foo {\nint bar(int a, char* b, int c = 10); \n};"
         << "int Foo::bar(int a, char* b, int c)\n{ a = c; b = new char; return a + *b; }"
@@ -369,6 +390,46 @@ void TestAssistants::testSignatureAssistant_data()
         << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0,25,0,31), "", SHOULD_ASSIST))
         << "class Foo {\nvoid bar(const Foo&);\n};"
         << "void Foo::bar(const Foo&)\n{}";
+
+    // see https://bugs.kde.org/show_bug.cgi?id=356179
+    QTest::newRow("keep_static_cpp")
+        << "class Foo { static void bar(int i); };"
+        << "void Foo::bar(int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0, 19, 0, 19), ", char c", SHOULD_ASSIST))
+        << "class Foo { static void bar(int i, char c); };"
+        << "void Foo::bar(int i, char c)\n{}";
+    QTest::newRow("keep_static_header")
+        << "class Foo { static void bar(int i); };"
+        << "void Foo::bar(int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::HeaderDoc, Range(0, 33, 0, 33), ", char c", SHOULD_ASSIST))
+        << "class Foo { static void bar(int i, char c); };"
+        << "void Foo::bar(int i, char c)\n{}";
+
+    // see https://bugs.kde.org/show_bug.cgi?id=356178
+    QTest::newRow("keep_default_args_cpp_before")
+        << "class Foo { void bar(bool b, int i = 0); };"
+        << "void Foo::bar(bool b, int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0, 14, 0, 14), "char c, ", SHOULD_ASSIST))
+        << "class Foo { void bar(char c, bool b, int i = 0); };"
+        << "void Foo::bar(char c, bool b, int i)\n{}";
+    QTest::newRow("keep_default_args_cpp_after")
+        << "class Foo { void bar(bool b, int i = 0); };"
+        << "void Foo::bar(bool b, int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::CppDoc, Range(0, 27, 0, 27), ", char c", SHOULD_ASSIST))
+        << "class Foo { void bar(bool b, int i = 0, char c = {} /* TODO */); };"
+        << "void Foo::bar(bool b, int i, char c)\n{}";
+    QTest::newRow("keep_default_args_header_before")
+        << "class Foo { void bar(bool b, int i = 0); };"
+        << "void Foo::bar(bool b, int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::HeaderDoc, Range(0, 29, 0, 29), "char c = 'A', ", SHOULD_ASSIST))
+        << "class Foo { void bar(bool b, char c = 'A', int i = 0); };"
+        << "void Foo::bar(bool b, char c, int i)\n{}";
+    QTest::newRow("keep_default_args_header_after")
+        << "class Foo { void bar(bool b, int i = 0); };"
+        << "void Foo::bar(bool b, int i)\n{}"
+        << (QList<StateChange>() << StateChange(Testbed::HeaderDoc, Range(0, 38, 0, 38), ", char c = 'A'", SHOULD_ASSIST))
+        << "class Foo { void bar(bool b, int i = 0, char c = 'A'); };"
+        << "void Foo::bar(bool b, int i, char c)\n{}";
 }
 
 void TestAssistants::testSignatureAssistant()
@@ -383,7 +444,6 @@ void TestAssistants::testSignatureAssistant()
         testbed.changeDocument(stateChange.document, stateChange.range, stateChange.newText, true);
 
         if (stateChange.result == SHOULD_ASSIST) {
-            QEXPECT_FAIL("swap_args_definition_side", "Parameters order is not tracked anywhere", Abort);
             QEXPECT_FAIL("change_function_type", "Clang sees that return type of out-of-line definition differs from that in the declaration and won't parse the code...", Abort);
             QVERIFY(staticAssistantsManager()->activeAssistant() && !staticAssistantsManager()->activeAssistant()->actions().isEmpty());
         } else {
