@@ -46,13 +46,11 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
-#include <ktexteditor_version.h>
-#if KTEXTEDITOR_VERSION < QT_VERSION_CHECK(5, 10, 0)
-Q_DECLARE_METATYPE(KTextEditor::Cursor);
-#endif
-
 QTEST_MAIN(TestCodeCompletion);
 
+static const auto NoMacroOrBuiltin = ClangCodeCompletionContext::ContextFilters(
+    ClangCodeCompletionContext::NoBuiltins | ClangCodeCompletionContext::NoMacros);
+
 using namespace KDevelop;
 
 using ClangCodeCompletionItemTester = CodeCompletionItemTester<ClangCodeCompletionContext>;
@@ -101,27 +99,19 @@ struct CompletionPriorityItems : public CompletionItems
 Q_DECLARE_TYPEINFO(CompletionPriorityItems, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(CompletionPriorityItems);
 
-void TestCodeCompletion::initTestCase()
-{
-    QLoggingCategory::setFilterRules(QStringLiteral("*.debug=false\ndefault.debug=true\nkdevelop.plugins.clang.debug=true\n"));
-    QVERIFY(qputenv("KDEV_DISABLE_PLUGINS", "kdevcppsupport"));
-    AutoTestShell::init({QStringLiteral("kdevclangsupport")});
-    TestCore::initialize();
-
-    ClangSettingsManager::self()->m_enableTesting = true;
-}
-
-void TestCodeCompletion::cleanupTestCase()
-{
-    TestCore::shutdown();
-}
-
 namespace {
 
+struct NoopTestFunction
+{
+    void operator()(const ClangCodeCompletionItemTester& /*tester*/) const
+    {
+    }
+};
+
+template<typename CustomTestFunction = NoopTestFunction>
 void executeCompletionTest(const ReferencedTopDUContext& top, const CompletionItems& expectedCompletionItems,
-                           const ClangCodeCompletionContext::ContextFilters& filters = ClangCodeCompletionContext::ContextFilters(
-                                ClangCodeCompletionContext::NoBuiltins |
-                                ClangCodeCompletionContext::NoMacros))
+                           const ClangCodeCompletionContext::ContextFilters& filters = NoMacroOrBuiltin,
+                           CustomTestFunction customTestFunction = {})
 {
     DUChainReadLocker lock;
     const ParseSessionData::Ptr sessionData(dynamic_cast<ParseSessionData*>(top->ast().data()));
@@ -153,22 +143,22 @@ void executeCompletionTest(const ReferencedTopDUContext& top, const CompletionIt
         qDebug() << "different results:\nactual:" << tester.names << "\nexpected:" << expectedCompletionItems.completions;
     }
     QCOMPARE(tester.names, expectedCompletionItems.completions);
+
+    customTestFunction(tester);
 }
 
+template<typename CustomTestFunction = NoopTestFunction>
 void executeCompletionTest(const QString& code, const CompletionItems& expectedCompletionItems,
-                           const ClangCodeCompletionContext::ContextFilters& filters = ClangCodeCompletionContext::ContextFilters(
-                                ClangCodeCompletionContext::NoBuiltins |
-                                ClangCodeCompletionContext::NoMacros))
+                           const ClangCodeCompletionContext::ContextFilters& filters = NoMacroOrBuiltin,
+                           CustomTestFunction customTestFunction = {})
 {
     TestFile file(code, "cpp");
     QVERIFY(file.parseAndWait(TopDUContext::AllDeclarationsContextsUsesAndAST));
-    executeCompletionTest(file.topContext(), expectedCompletionItems, filters);
+    executeCompletionTest(file.topContext(), expectedCompletionItems, filters, customTestFunction);
 }
 
 void executeCompletionPriorityTest(const QString& code, const CompletionPriorityItems& expectedCompletionItems,
-                           const ClangCodeCompletionContext::ContextFilters& filters = ClangCodeCompletionContext::ContextFilters(
-                                ClangCodeCompletionContext::NoBuiltins |
-                                ClangCodeCompletionContext::NoMacros))
+                           const ClangCodeCompletionContext::ContextFilters& filters = NoMacroOrBuiltin)
 {
     TestFile file(code, "cpp");
     QVERIFY(file.parseAndWait(TopDUContext::AllDeclarationsContextsUsesAndAST));
@@ -205,9 +195,7 @@ void executeCompletionPriorityTest(const QString& code, const CompletionPriority
 }
 
 void executeMemberAccessReplacerTest(const QString& code, const CompletionItems& expectedCompletionItems,
-                                     const ClangCodeCompletionContext::ContextFilters& filters = ClangCodeCompletionContext::ContextFilters(
-                                            ClangCodeCompletionContext::NoBuiltins |
-                                            ClangCodeCompletionContext::NoMacros))
+                                     const ClangCodeCompletionContext::ContextFilters& filters = NoMacroOrBuiltin)
 {
     TestFile file(code, "cpp");
 
@@ -447,7 +435,7 @@ void TestCodeCompletion::testClangCodeCompletion_data()
             "instance.itemT", "main",
             "pInstance", "pInstance->itemT",
         }};
-        QTest::newRow("look-ahead item access")
+    QTest::newRow("look-ahead item access")
         << "class Class { public: int publicInt; protected: int protectedInt; private: int privateInt;};"
            "int main() {Class cl; int i =\n "
         << CompletionItems{{1, 0}, {
@@ -456,7 +444,7 @@ void TestCodeCompletion::testClangCodeCompletion_data()
             "i", "main",
         }};
 
-        QTest::newRow("look-ahead auto item")
+    QTest::newRow("look-ahead auto item")
         << "struct LookAhead { int intItem; };"
            "int main() {auto instance = LookAhead(); int i = \n "
         << CompletionItems{{1, 0}, {
@@ -587,6 +575,22 @@ void TestCodeCompletion::testImplement_data()
            "}; \n"
         << CompletionItems{{2, 0}, {"bar(char c, int i)"}};
 
+    QTest::newRow("anonymous-namespace")
+        << R"(
+                namespace {
+                    int bar(char c, int i);
+                };
+            )"
+        << CompletionItems{{3, 0}, {"bar(char c, int i)"}};
+
+    QTest::newRow("anonymous-namespace2")
+        << R"(
+                namespace {
+                    int bar(char c, int i);
+                };
+           )"
+        << CompletionItems{{4, 0}, {}};
+
     QTest::newRow("namespace2")
         << "namespace Foo { \n"
            "int bar(char c, int i); \n\n"
@@ -715,6 +719,33 @@ void TestCodeCompletion::testImplement_data()
            "  ~Foo() =default;\n"
            "};\n"
         << CompletionItems{{5,1}, {"Foo::Foo()"}};
+
+    QTest::newRow("bug355163")
+        << R"(
+                #include <type_traits>
+                namespace test {
+
+                template<typename T, typename U>
+                struct IsSafeConversion : public std::is_same<T, typename std::common_type<T, U>::type>
+                {
+
+                };
+
+                } // namespace test
+            )"
+        << CompletionItems{{7,0}, {}};
+
+    QTest::newRow("bug355954")
+        << R"(
+                struct Hello {
+                    struct Private;
+                };
+
+                struct Hello::Private {
+                    void test();
+                };
+            )"
+        << CompletionItems{{8,0}, {"Hello::Private::test()"}};
 }
 
 void TestCodeCompletion::testImplementOtherFile()
@@ -818,16 +849,11 @@ void TestCodeCompletion::testIncludePathCompletion()
     auto item = tester.findItem(itemId);
     QVERIFY(item);
 
-    KTextEditor::Editor* editor = KTextEditor::Editor::instance();
-    QVERIFY(editor);
-
-    auto doc = std::unique_ptr<KTextEditor::Document>(editor->createDocument(this));
-    QVERIFY(doc.get());
-    QVERIFY(doc->openUrl(file.url().toUrl()));
-
-    QWidget parent;
-    auto view = doc->createView(&parent);
-    item->execute(view, KTextEditor::Range(cursor, cursor));
+    auto view = createView(file.url().toUrl(), this);
+    qDebug() << view.get();
+    QVERIFY(view.get());
+    auto doc = view->document();
+    item->execute(view.get(), KTextEditor::Range(cursor, cursor));
     QCOMPARE(doc->text(), result);
 
     const auto newCursor = view->cursorPosition();
@@ -866,9 +892,7 @@ void TestCodeCompletion::testOverloadedFunctions()
     lock.unlock();
 
     const auto context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(), {1, 0}, QString());
-    context->setFilters(ClangCodeCompletionContext::ContextFilters(
-                            ClangCodeCompletionContext::NoBuiltins |
-                            ClangCodeCompletionContext::NoMacros));
+    context->setFilters(NoMacroOrBuiltin);
     lock.lock();
     const auto tester = ClangCodeCompletionItemTester(QExplicitlySharedDataPointer<ClangCodeCompletionContext>(context));
     QCOMPARE(tester.items.size(), 3);
@@ -957,9 +981,7 @@ void TestCodeCompletion::testVariableScope()
     lock.unlock();
 
     const auto context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(), {2, 0}, QString());
-    context->setFilters(ClangCodeCompletionContext::ContextFilters(
-                            ClangCodeCompletionContext::NoBuiltins |
-                            ClangCodeCompletionContext::NoMacros));
+    context->setFilters(NoMacroOrBuiltin);
     lock.lock();
     const auto tester = ClangCodeCompletionItemTester(QExplicitlySharedDataPointer<ClangCodeCompletionContext>(context));
 
@@ -1045,9 +1067,7 @@ void TestCodeCompletion::testArgumentHintCompletionDefaultParameters()
     lock.unlock();
 
     const auto context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(), {1, 2}, QString());
-    context->setFilters(ClangCodeCompletionContext::ContextFilters(
-                            ClangCodeCompletionContext::NoBuiltins |
-                            ClangCodeCompletionContext::NoMacros));
+    context->setFilters(NoMacroOrBuiltin);
     lock.lock();
     const auto tester = ClangCodeCompletionItemTester(QExplicitlySharedDataPointer<ClangCodeCompletionContext>(context));
     QExplicitlySharedDataPointer<KDevelop::CompletionTreeItem> f;
@@ -1064,3 +1084,40 @@ void TestCodeCompletion::testArgumentHintCompletionDefaultParameters()
     const QString itemDisplay = tester.itemData(f).toString() + tester.itemData(f, KTextEditor:: CodeCompletionModel::Arguments).toString();
     QCOMPARE(QStringLiteral("f(int i, int j, double k)"), itemDisplay);
 }
+
+void TestCodeCompletion::testCompleteFunction()
+{
+    QFETCH(QString, code);
+    QFETCH(CompletionItems, expectedItems);
+    QFETCH(QString, itemToExecute);
+    QFETCH(QString, expectedCode);
+
+    auto executeItem = [=] (const ClangCodeCompletionItemTester& tester) {
+        auto item = tester.findItem(itemToExecute);
+        QVERIFY(item);
+        auto view = createView(tester.completionContext->duContext()->url().toUrl(), this);
+        item->execute(view.get(), view->document()->wordRangeAt(expectedItems.position));
+        QCOMPARE(view->document()->text(), expectedCode);
+    };
+    executeCompletionTest(code, expectedItems, NoMacroOrBuiltin, executeItem);
+}
+
+void TestCodeCompletion::testCompleteFunction_data()
+{
+    QTest::addColumn<QString>("code");
+    QTest::addColumn<CompletionItems>("expectedItems");
+    QTest::addColumn<QString>("itemToExecute");
+    QTest::addColumn<QString>("expectedCode");
+
+    QTest::newRow("add-parens")
+        << "int foo();\nint main() {\n\n}"
+        << CompletionItems({2, 0}, {"foo", "main"})
+        << "foo"
+        << "int foo();\nint main() {\nfoo()\n}";
+
+    QTest::newRow("keep-parens")
+        << "int foo();\nint main() {\nfoo();\n}"
+        << CompletionItems({2, 0}, {"foo", "main"})
+        << "main"
+        << "int foo();\nint main() {\nmain();\n}";
+}
