@@ -21,12 +21,13 @@
  */
 
 #include "cppclasshelper.h"
+#include "../debug.h"
 #include <codecompletion/missingincludeitem.h>
 #include <language/duchain/declaration.h>
 #include <language/codegen/documentchangeset.h>
 #include <language/codegen/codedescription.h>
 
-#include <KTemporaryFile>
+#include <QTemporaryFile>
 
 using namespace KDevelop;
 
@@ -40,15 +41,14 @@ CppClassHelper::~CppClassHelper()
 
 }
 
-TemplateClassGenerator* CppClassHelper::createGenerator(const KUrl& baseUrl)
+TemplateClassGenerator* CppClassHelper::createGenerator(const QUrl& baseUrl)
 {
     return new CppTemplateNewClass(baseUrl);
 }
 
 QList<DeclarationPointer> CppClassHelper::defaultMethods(const QString& name) const
 {
-    KTemporaryFile file;
-    file.setSuffix( ".cpp" );
+    QTemporaryFile file(QDir::tempPath() + QLatin1String("/class_XXXXXX") + QLatin1String(".cpp"));
     file.setAutoRemove(false);
     file.open();
     QTextStream stream(&file);
@@ -83,7 +83,7 @@ QList<DeclarationPointer> CppClassHelper::defaultMethods(const QString& name) co
     return methods;
 }
 
-CppTemplateNewClass::CppTemplateNewClass(const KUrl& url)
+CppTemplateNewClass::CppTemplateNewClass(const QUrl& url)
 : TemplateClassGenerator(url)
 {
 
@@ -164,8 +164,8 @@ QVariantHash CppTemplateNewClass::extraVariables()
     QStringList includedFiles;
     DUChainReadLocker locker(DUChain::lock());
 
-    KUrl sourceUrl;
-    QHash<QString, KUrl> urls = fileUrls();
+    QUrl sourceUrl;
+    QHash<QString, QUrl> urls = fileUrls();
     if (!urls.isEmpty())
     {
         sourceUrl = urls.constBegin().value();
@@ -174,7 +174,7 @@ QVariantHash CppTemplateNewClass::extraVariables()
     {
         // includeDirectiveFromUrl() expects a header URL
         sourceUrl = baseUrl();
-        sourceUrl.addPath(name().toLower() + ".h");
+        sourceUrl.setPath(sourceUrl.path() + '/' + ".h");
     }
 
     foreach (const DeclarationPointer& base, directBaseClasses())
@@ -183,11 +183,11 @@ QVariantHash CppTemplateNewClass::extraVariables()
         {
             continue;
         }
-        kDebug() << "Looking for includes for class" << base->identifier().toString();
-        KSharedPtr<Cpp::MissingIncludeCompletionItem> item = Cpp::includeDirectiveFromUrl(sourceUrl, IndexedDeclaration(base.data()));
+        qCDebug(CPP) << "Looking for includes for class" << base->identifier().toString();
+        QExplicitlySharedDataPointer<Cpp::MissingIncludeCompletionItem> item = Cpp::includeDirectiveFromUrl(sourceUrl, IndexedDeclaration(base.data()));
         if(item)
         {
-            kDebug() << "Found one in" << item->m_canonicalPath;
+            qCDebug(CPP) << "Found one in" << item->m_canonicalPath;
             includedFiles << item->m_addedInclude;
         }
     }
