@@ -32,15 +32,12 @@
 #include "parser/dumptree.h"
 #include "parser/memorypool.h"
 
-#include <unistd.h>
-
 #include <QFile>
 #include <QByteArray>
 #include <QReadWriteLock>
 #include <QReadLocker>
 
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <ThreadWeaver/Thread>
 
@@ -50,27 +47,28 @@
 #include "cppduchain/usebuilder.h"
 #include "preprocessjob.h"
 #include "environmentmanager.h"
+#include "debug.h"
 
 #include <language/duchain/topducontext.h>
 #include <language/duchain/duchain.h>
+#include <language/duchain/duchaindumper.h>
 #include <language/duchain/duchainpointer.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchainutils.h>
 #include <language/duchain/dumpdotgraph.h>
-#include <language/duchain/dumpchain.h>
 #include <language/interfaces/iastcontainer.h>
 
 #include <language/backgroundparser/parsejob.h>
 #include <language/backgroundparser/urlparselock.h>
 #include <language/backgroundparser/backgroundparser.h>
 
-#include <interfaces/ilanguage.h>
 #include <interfaces/iuicontroller.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <cpppreprocessenvironment.h>
 #include <language/checks/dataaccessrepository.h>
 #include <language/checks/controlflowgraph.h>
+#include <threadweaver/queue.h>
 #include <controlflowgraphbuilder.h>
 #include <usedecoratorvisitor.h>
 
@@ -131,11 +129,11 @@ CPPParseJob::CPPParseJob( const IndexedString& url, ILanguageSupport* languageSu
         m_needsUpdate( true )
 {
     if( !m_parentPreprocessor ) {
-        addJob(m_preprocessJob = new PreprocessJob(this));
-        addJob(m_parseJob = new CPPInternalParseJob(this));
+        addJob(m_preprocessJob = ThreadWeaver::JobPointer(new PreprocessJob(this)));
+        addJob(m_parseJob = ThreadWeaver::JobPointer(new CPPInternalParseJob(this)));
     } else {
-        m_preprocessJob = 0;
-        m_parseJob = 0;
+        m_preprocessJob.clear();
+        m_parseJob.clear();
         //The preprocessor will call parseForeground() to preprocess & parse instantly
     }
 }
@@ -174,10 +172,10 @@ void CPPParseJob::parseForeground() {
     //Create the sub-jobs and directly execute them.
     Q_ASSERT( !m_preprocessJob && !m_parseJob );
 
-    m_preprocessJob = new PreprocessJob(this);
-    m_parseJob = new CPPInternalParseJob(this);
-    m_preprocessJob->run();
-    m_parseJob->run();
+    m_preprocessJob = ThreadWeaver::JobPointer(new PreprocessJob(this));
+    m_parseJob = ThreadWeaver::JobPointer(new CPPInternalParseJob(this));
+    m_preprocessJob->blockingExecute();
+    m_parseJob->blockingExecute();
 }
 
 Path CPPParseJob::includedFromPath() const {
@@ -214,24 +212,22 @@ void CPPParseJob::mergeDefines(CppPreprocessEnvironment& env) const
 {
   //m_includePathsComputed is filled when includePaths() is called
   masterJob()->indexedIncludePaths();
-  
+
   if(ICore::self()->shuttingDown())
     return; //If the system is shutting down, include-paths were not computed properly
-  
+
   Q_ASSERT(masterJob()->m_includePathsComputed);
-  
+
   QHash<QString, QString> defines = masterJob()->m_includePathsComputed->defines();
-  
+
   ///@todo Most probably, the same macro-sets will be calculated again and again.
   ///           One ReferenceCountedMacroSet would be enough.
-  
-  kDebug() << "DEFINES:" << defines;
-  
+
   for(QHash<QString, QString>::const_iterator it = defines.constBegin(); it != defines.constEnd(); ++it)
   {
-    rpp::pp_macro* m = new rpp::pp_macro(IndexedString(it.key()));
-    m->setDefinitionText( *it );
-    
+    rpp::pp_macro m(IndexedString(it.key()));
+    m.setDefinitionText( *it );
+
     //Call rpp::Environment::setMacro directly, so we don't add the macro to the environment-file.
     //It should be only part of the environment.
     env.rpp::Environment::setMacro(m);
@@ -242,7 +238,7 @@ const QList<IndexedString>& CPPParseJob::indexedIncludePaths() const {
     //If a lock was held here, we would get deadlocks
     if( ICore::self()->shuttingDown() )
       return m_includePaths;
-    
+
     if( masterJob() == this ) {
         if( !m_includePathsComputed ) {
             Q_ASSERT(!DUChain::lock()->currentThreadHasReadLock() && !DUChain::lock()->currentThreadHasWriteLock());
@@ -276,22 +272,19 @@ CPPParseJob::~CPPParseJob()
 }
 
 KDevelop::ModificationRevisionSet CPPParseJob::includePathDependencies() const {
-  if(m_includePathsComputed)
-    return m_includePathsComputed->m_includePathDependency;
-
   return KDevelop::ModificationRevisionSet();
 }
 
 CPPParseJob* CPPParseJob::masterJob() {
     if( parentPreprocessor() )
-        return static_cast<CPPParseJob*>(parentPreprocessor()->parent())->masterJob();
+        return parentPreprocessor()->parentJob()->masterJob();
     else
         return this;
 }
 
 const CPPParseJob* CPPParseJob::masterJob() const {
     if( parentPreprocessor() )
-        return static_cast<CPPParseJob*>(parentPreprocessor()->parent())->masterJob();
+        return parentPreprocessor()->parentJob()->masterJob();
     else
         return this;
 }
@@ -325,7 +318,7 @@ void CPPParseJob::addIncludedFile(KDevelop::ReferencedTopDUContext duChain, int
 }
 
 void CPPParseJob::setProxyEnvironmentFile( Cpp::EnvironmentFile* file ) {
-    m_proxyEnvironmentFile = KSharedPtr<Cpp::EnvironmentFile>(file);
+    m_proxyEnvironmentFile = QExplicitlySharedDataPointer<Cpp::EnvironmentFile>(file);
 }
 
 Cpp::EnvironmentFile* CPPParseJob::proxyEnvironmentFile() {
@@ -334,7 +327,7 @@ Cpp::EnvironmentFile* CPPParseJob::proxyEnvironmentFile() {
 
 void CPPParseJob::setContentEnvironmentFile( Cpp::EnvironmentFile* file ) {
     //Q_ASSERT(!file || file->identity().flags() & IdentifiedFile::Content);
-    m_contentEnvironmentFile = KSharedPtr<Cpp::EnvironmentFile>(file);
+    m_contentEnvironmentFile = QExplicitlySharedDataPointer<Cpp::EnvironmentFile>(file);
 }
 
 void CPPParseJob::addPreprocessorProblem(const ProblemPointer problem) {
@@ -359,8 +352,7 @@ const IncludeFileList& CPPParseJob::includedFiles() const {
 
 CPPParseJob * CPPInternalParseJob::parentJob() const
 {
-    Q_ASSERT(parent());
-    return static_cast<CPPParseJob*>(const_cast<QObject*>(parent()));
+    return m_parentJob;
 }
 
 const KTextEditor::Range& CPPParseJob::textRangeToParse() const
@@ -369,7 +361,7 @@ const KTextEditor::Range& CPPParseJob::textRangeToParse() const
 }
 
 CPPInternalParseJob::CPPInternalParseJob(CPPParseJob * parent)
-    : ThreadWeaver::Job(parent)
+    : m_parentJob(parent)
     , m_initialized(false)
     , m_priority(0)
 {
@@ -382,7 +374,7 @@ LineContextPair contentFromProxy(LineContextPair ctx) {
           ReferencedTopDUContext ref(ctx.context);
         }
         if(ctx.context->importedParentContexts().isEmpty()) {
-          kWarning() << "proxy-context for" << ctx.context->url().str() << "has no imports!" << ctx.context->ownIndex();
+          qCWarning(CPP) << "proxy-context for" << ctx.context->url().str() << "has no imports!" << ctx.context->ownIndex();
           ///@todo Find out how this can happen
 //           Q_ASSERT(0);
           return LineContextPair(0, 0);
@@ -420,46 +412,46 @@ void CPPInternalParseJob::highlightIfNeeded()
     DUChainReadLocker l(DUChain::lock());
     ReferencedTopDUContext standardContext = DUChainUtils::standardContextForUrl(parentJob()->document().toUrl());
 
-    kDebug( 9007 ) << "Highlighting" << parentJob()->document().str();
+    qCDebug(CPP) << "Highlighting" << parentJob()->document().str();
     //If the document has a smart-range, at least re-do the highlighting
     l.unlock();
     if ( parentJob()->cpp() && parentJob()->cpp()->codeHighlighting() )
       parentJob()->cpp()->codeHighlighting()->highlightDUChain( standardContext.data() );
 }
 
-void CPPInternalParseJob::run()
+void CPPInternalParseJob::run(ThreadWeaver::JobPointer pointer, ThreadWeaver::Thread* thread)
 {
     //Happens during shutdown
-    if(ICore::self()->shuttingDown() || !ICore::self()->languageController()->language("C++")->languageSupport() || !parentJob()->cpp())
+    if(ICore::self()->shuttingDown() || !ICore::self()->languageController()->language("C++") || !parentJob()->cpp())
       return;
-    
+
     //If we have a parent, the parse-mutex is already locked
-    QReadLocker lock(parentJob()->parentPreprocessor() ? 0 : parentJob()->cpp()->language()->parseLock());
-    if(!ICore::self()->languageController()->language("C++")->languageSupport() || !parentJob()->cpp())
+    QReadLocker lock(parentJob()->parentPreprocessor() ? 0 : parentJob()->cpp()->parseLock());
+    if(!ICore::self()->languageController()->language("C++") || !parentJob()->cpp())
       return;
-    
+
     initialize();
 
     if(updatingContentContext)
       parentJob()->translateDUChainToRevision(updatingContentContext.data());
-    
+
     if(updatingProxyContext)
       parentJob()->translateDUChainToRevision(updatingProxyContext.data());
-    
+
     UrlParseLock urlLock(parentJob()->document());
 
     if(!parentJob()->needsUpdate()) {
       parentJob()->processDelayedImports();
-      kDebug( 9007 ) << "===-- ALREADY UP TO DATE --===> " << parentJob()->document().str();
+      qCDebug(CPP) << "===-- ALREADY UP TO DATE --===> " << parentJob()->document().str();
       highlightIfNeeded();
       return;
     }
     if(!parentJob()->contentEnvironmentFile()) {
       //May happen when the file could not be opened or similar
-      kDebug( 9007 ) << "===-- Problem: Preprocessor did not create environment-file, skipping --===> " << parentJob()->document().str();
+      qCDebug(CPP) << "===-- Problem: Preprocessor did not create environment-file, skipping --===> " << parentJob()->document().str();
       return;
     }
-    kDebug( 9007 ) << "===-- PARSING --===> "
+    qCDebug(CPP) << "===-- PARSING --===> "
     << parentJob()->document().str();
 
 
@@ -548,7 +540,7 @@ void CPPInternalParseJob::run()
         newFeatures = (TopDUContext::Features)(newFeatures | contentContext->features());
 
       if(newFeatures & TopDUContext::ForceUpdate)
-        kDebug() << "update enforced";
+        qCDebug(CPP) << "update enforced";
 
       ///At some point, we have to give up on features again, else processing will be just too slow.
       ///Simple solution for now: Always go down to the minimum required level.
@@ -556,10 +548,10 @@ void CPPInternalParseJob::run()
         newFeatures = parentJob()->minimumFeatures();
 
       bool keepAST = newFeatures & TopDUContext::AST;
-      
+
       //Remove update-flags like 'Recursive' or 'ForceUpdate', and the AST flag
       newFeatures = (TopDUContext::Features)(newFeatures & TopDUContext::AllDeclarationsContextsAndUses);
-      
+
       TranslationUnitAST* ast = 0L;
 
       Control control;
@@ -570,19 +562,19 @@ void CPPInternalParseJob::run()
         ast = parser.parse( parentJob()->parseSession().data() );
 
         //This will be set to true if the duchain data should be left untouched
-        if((ast->hadMissingCompoundTokens || control.hasProblem(KDevelop::ProblemData::Lexer)) && updatingContentContext) {
+        if((ast->hadMissingCompoundTokens || control.hasProblem(IProblem::Lexer)) && updatingContentContext) {
           //Make sure we don't update into a completely invalid state where everything is invalidated temporarily.
           DUChainWriteLocker l(DUChain::lock());
 
           if((updatingContentContext->features() & parentJob()->minimumFeatures()) ==  parentJob()->minimumFeatures() &&
             isOpenInEditor &&
               updatingContentContext->parsingEnvironmentFile()->modificationRevision().modificationTime == ModificationRevision::revisionForFile(updatingContentContext->url()).modificationTime && CppLanguageSupport::self()->codeHighlighting()->hasHighlighting(parentJob()->document())) {
-            kDebug() << "not processing" << updatingContentContext->url().str() << "because of missing compound tokens";
+            qCDebug(CPP) << "not processing" << updatingContentContext->url().str() << "because of missing compound tokens";
             ICore::self()->uiController()->showErrorMessage(i18n("Not updating duchain for %1", parentJob()->document().toUrl().fileName()), 1);
             l.unlock();
             doNotChangeDUChain = true;
             ProblemPointer problem(new Problem);
-            problem->setSource(ProblemData::Parser);
+            problem->setSource(IProblem::Parser);
             problem->setDescription("Not updating the DUChain because of serious document inconsistency");
             control.reportProblem(problem);
           }
@@ -600,7 +592,7 @@ void CPPInternalParseJob::run()
         }
       }
 
-      kDebug( 9007 ) << (contentContext ? "updating" : "building") << "duchain for" << parentJob()->document().str();
+      qCDebug(CPP) << (contentContext ? "updating" : "building") << "duchain for" << parentJob()->document().str();
 
       uint oldItemCount = 0;
       if(contentContext) {
@@ -618,9 +610,9 @@ void CPPInternalParseJob::run()
       {
         declarationBuilder.setOnlyComputeVisible(true);
         declarationBuilder.setComputeSimplified(true);
-        kDebug() << "computing simplified";
+        qCDebug(CPP) << "computing simplified";
       }else if(newFeatures == TopDUContext::Empty) {
-        kDebug() << "computing empty";
+        qCDebug(CPP) << "computing empty";
         declarationBuilder.setComputeEmpty(true);
       }
 
@@ -644,7 +636,7 @@ void CPPInternalParseJob::run()
           ///      While searching, always use the perspective of the proxy. Even better: Change the context-system so proxy-contexts become completely valid contexts from the outside perspective,
           ///      that import all their imports, and that share all their content except the imports/environment-information with all the other proxy contexts for that file, and with one content-context.
           ///      Main problem: Contained Declarations/DUContexts point at their parent top-context. Which proxy-context should they point at?
-          //kDebug() << "A significant change was recorded, all following contexts will be updated";
+          //qCDebug(CPP) << "A significant change was recorded, all following contexts will be updated";
           //parentJob()->masterJob()->setNeedUpdateEverything(true);
         }
 
@@ -656,7 +648,7 @@ void CPPInternalParseJob::run()
           if(contentContext->childContexts().size() + contentContext->localDeclarations().size() == 0) {
             if(oldItemCount != 0) {
               //To catch some problems
-              kDebug(9007) << "All items in" << parentJob()->document().str() << "have been extincted, previous count:" << oldItemCount << "current identity offset:" << contentEnvironmentFile->identityOffset();
+              qCDebug(CPP) << "All items in" << parentJob()->document().str() << "have been extincted, previous count:" << oldItemCount << "current identity offset:" << contentEnvironmentFile->identityOffset();
             }
           }
         }
@@ -695,7 +687,7 @@ void CPPInternalParseJob::run()
             foreach(const DUContext::Import &ctx, imports) {
                 if(ctx.context(0) && !encounteredIncludeUrls.contains(ctx.context(0)->url()) && contentEnvironmentFile->missingIncludeFiles().set().count() == 0 && (!proxyEnvironmentFile || proxyEnvironmentFile->missingIncludeFiles().set().count() == 0)) {
                     contentContext->removeImportedParentContext(ctx.context(0));
-                    kDebug( 9007 ) << "removing not encountered import " << ctx.context(0)->url().str();
+                    qCDebug(CPP) << "removing not encountered import " << ctx.context(0)->url().str();
                 }
             }
         }
@@ -722,14 +714,14 @@ void CPPInternalParseJob::run()
           }
         }
       }
-      
+
       if (!parentJob()->abortRequested() && isOpenInEditor) {
         if ( parentJob()->cpp() && parentJob()->cpp()->codeHighlighting() )
         {
           parentJob()->cpp()->codeHighlighting()->highlightDUChain( contentContext );
         }
       }
-      
+
 
       ///Now mark the context as not being updated. This MUST be done or we will be waiting forever in a loop
       {
@@ -737,12 +729,11 @@ void CPPInternalParseJob::run()
         contentContext->setFeatures(newFeatures);
         if(proxyContext)
           proxyContext->setFeatures(newFeatures);
-        contentContext->setFlags( (TopDUContext::Flags)(contentContext->flags() & (~TopDUContext::UpdatingContext)) );
 
         //Now that the Ast is fully built, add it to the TopDUContext if requested
         if(keepAST)
         {
-          kDebug() << "AST Is being kept for" << parentJob()->document().toUrl();
+          qCDebug(CPP) << "AST Is being kept for" << parentJob()->document().toUrl();
           contentContext->setAst(IAstContainer::Ptr( parentJob()->parseSession().data() ));
           parentJob()->parseSession()->setASTNodeParents();
         }
@@ -760,7 +751,7 @@ void CPPInternalParseJob::run()
         if(proxyContext && contentContext)
           proxyContext->setFeatures(contentContext->features());
       }
-      kDebug() << "keeping duchain";
+      qCDebug(CPP) << "keeping duchain";
       highlightIfNeeded();
     }
 
@@ -785,7 +776,7 @@ void CPPInternalParseJob::run()
           continue;
         Q_ASSERT(context.context);
         if(!contentContext->imports(context.context.data(), CursorInRevision::invalid())) {
-          kWarning() << "Context should be imported, but is not:" << contentContext->url().str() << " <- " << context.context->url().str();
+          qCWarning(CPP) << "Context should be imported, but is not:" << contentContext->url().str() << " <- " << context.context->url().str();
         }
       }
     }
@@ -865,23 +856,25 @@ void CPPInternalParseJob::run()
     if ( !parentJob()->parentPreprocessor() ) {
             DUChainReadLocker lock(DUChain::lock());
 #ifdef DUMP_DUCHAIN
-        kDebug( 9007 ) << "================== duchain ==================";
-        KDevelop::dumpDUContext(contentContext);
+        qCDebug(CPP) << "================== duchain ==================";
+        DUChainDumper dumper;
+        dumper.dump(contentContext);
 #endif
 
         //KDevelop::DumpDotGraph dumpGraph;
-        //kDebug(9007) << "Dot-graph:\n" << dumpGraph.dotGraph(topContext, true);
+        //qCDebug(CPP) << "Dot-graph:\n" << dumpGraph.dotGraph(topContext, true);
     }
 
-    kDebug( 9007 ) << "===-- Parsing finished --===>" << parentJob()->document().str();
+    qCDebug(CPP) << "===-- Parsing finished --===>" << parentJob()->document().str();
 
     parentJob()->processDelayedImports();
 }
 
 void CPPParseJob::processDelayedImports() {
+  QSharedPointer<CPPInternalParseJob> parseJob = this->parseJob();
   if(!m_delayedImports.isEmpty()) {
     foreach(const LineJobPair& job, m_delayedImports)
-      job.first->addDelayedImporter(LineContextPair(m_parseJob->proxyContext ? m_parseJob->proxyContext : m_parseJob->contentContext, job.second));
+      job.first->addDelayedImporter(LineContextPair(parseJob->proxyContext ? parseJob->proxyContext : parseJob->contentContext, job.second));
     m_delayedImports.clear();
   }
   if(!m_delayedImporters.isEmpty()) {
@@ -889,23 +882,23 @@ void CPPParseJob::processDelayedImports() {
     foreach(const LineContextPair& context, m_delayedImporters) {
       Q_ASSERT(context.context->parsingEnvironmentFile());
       if(context.context->parsingEnvironmentFile()->isProxyContext()) {
-        Q_ASSERT(m_parseJob->proxyContext);
-        context.context->addImportedParentContext(m_parseJob->proxyContext.data(), CursorInRevision(context.sourceLine, 0));
+        Q_ASSERT(parseJob->proxyContext);
+        context.context->addImportedParentContext(parseJob->proxyContext.data(), CursorInRevision(context.sourceLine, 0));
         Cpp::EnvironmentFile* cppEnvFile = dynamic_cast<Cpp::EnvironmentFile*>(context.context->parsingEnvironmentFile().data());
         Q_ASSERT(cppEnvFile);
-        cppEnvFile->merge(dynamic_cast<Cpp::EnvironmentFile&>(*m_parseJob->proxyContext->parsingEnvironmentFile().data()));
+        cppEnvFile->merge(dynamic_cast<Cpp::EnvironmentFile&>(*parseJob->proxyContext->parsingEnvironmentFile().data()));
         context.context->updateImportsCache();
       }
-      Q_ASSERT(m_parseJob->contentContext);
+      Q_ASSERT(parseJob->contentContext);
       LineContextPair content = contentFromProxy(context);
       if(!content.context)
         continue;
       Q_ASSERT(content.context);
-      content.context->addImportedParentContext(m_parseJob->proxyContext.data(), CursorInRevision(content.sourceLine, 0));
+      content.context->addImportedParentContext(parseJob->proxyContext.data(), CursorInRevision(content.sourceLine, 0));
       content.context->updateImportsCache();
       Cpp::EnvironmentFile* cppEnvFile = dynamic_cast<Cpp::EnvironmentFile*>(content.context->parsingEnvironmentFile().data());
       Q_ASSERT(cppEnvFile);
-      cppEnvFile->merge(dynamic_cast<Cpp::EnvironmentFile&>(*m_parseJob->contentContext->parsingEnvironmentFile().data()));
+      cppEnvFile->merge(dynamic_cast<Cpp::EnvironmentFile&>(*parseJob->contentContext->parsingEnvironmentFile().data()));
     }
   }
 }
@@ -927,9 +920,9 @@ ParseSession::Ptr CPPParseJob::parseSession() const
     return m_session;
 }
 
-CPPInternalParseJob * CPPParseJob::parseJob() const
+QSharedPointer<CPPInternalParseJob> CPPParseJob::parseJob() const
 {
-    return m_parseJob;
+    return m_parseJob.dynamicCast<CPPInternalParseJob>();
 }
 
 int CPPInternalParseJob::priority() const
@@ -953,7 +946,7 @@ TopDUContext::Features CPPParseJob::slaveMinimumFeatures() const
       slaveMinimumFeatures = (TopDUContext::Features)(minimumFeatures() & (~TopDUContext::ForceUpdate));
     else if((minimumFeatures() & TopDUContext::VisibleDeclarationsAndContexts) == TopDUContext::VisibleDeclarationsAndContexts)
       slaveMinimumFeatures = TopDUContext::VisibleDeclarationsAndContexts;
-    
+
     if((minimumFeatures() & TopDUContext::ForceUpdateRecursive) == TopDUContext::ForceUpdateRecursive)
       slaveMinimumFeatures = (TopDUContext::Features)(slaveMinimumFeatures | TopDUContext::ForceUpdateRecursive);
 
@@ -977,5 +970,4 @@ DataAccessRepository* CPPParseJob::dataAccessInformation()
   return ret;
 }
 
-#include "cppparsejob.moc"
 
