@@ -27,9 +27,10 @@
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/topducontext.h>
-#include <language/interfaces/idefinesandincludesmanager.h>
+#include <custom-definesandincludes/idefinesandincludesmanager.h>
 
 #include "cppduchain/environmentmanager.h"
+#include "debug.h"
 
 #include <KLocalizedString>
 #include <QThread>
@@ -37,12 +38,10 @@
 
 using namespace KDevelop;
 
-const bool enableIncludePathResolution = true;
-
 IncludePathComputer::IncludePathComputer(const QString& file)
   : m_source(file)
   , m_ready(false)
-  , m_gotPathsFromManager(false)
+  , m_noProject(true)
 {
 }
 
@@ -60,25 +59,18 @@ void IncludePathComputer::computeForeground()
   }
 
   if (m_source.isEmpty()) {
-    kDebug() << "cannot compute include-paths without source-file";
+    qCDebug(CPP) << "cannot compute include-paths without source-file";
     return;
   }
 
   const IndexedString indexedSource(m_source);
-  bool noProject = true;
   foreach (IProject *project, ICore::self()->projectController()->projects()) {
     QList<ProjectFileItem*> files = project->filesForPath(indexedSource);
     if (files.isEmpty()) {
       continue;
     }
 
-    noProject = false;
-    IBuildSystemManager* buildManager = project->buildSystemManager();
-    if (!buildManager) {
-      // We found the project, but no build manager!!
-      kDebug() << "didn't get build manager for project:" << project->name();
-      continue;
-    }
+    m_noProject = false;
 
     auto idm = IDefinesAndIncludesManager::manager();
 
@@ -102,34 +94,27 @@ void IncludePathComputer::computeForeground()
     }
 
     m_projectName = project->name();
-    m_projectDirectory = project->path();
-    m_effectiveBuildDirectory = m_buildDirectory = buildManager->buildDirectory(project->projectItem());
-    kDebug(9007) << "Got build-directory from project manager:" << m_effectiveBuildDirectory;
 
-    if (m_projectDirectory == m_effectiveBuildDirectory) {
-      m_projectDirectory.clear();
-      m_effectiveBuildDirectory.clear();
+    for (const auto& dir : idm->includes(file, IDefinesAndIncludesManager::Type(IDefinesAndIncludesManager::UserDefined))){
+      addInclude(dir);
+    }
+    m_defines = idm->defines(file);
+
+    qCDebug(CPP) << "Got " << dirs.count() << " include-paths from build-manager";
+    foreach (const Path& dir, dirs) {
+      addInclude(dir);
     }
 
-      for (const auto& dir : idm->includes(file, IDefinesAndIncludesManager::Type(IDefinesAndIncludesManager::UserDefined | IDefinesAndIncludesManager::CompilerSpecific))){
-        addInclude(dir);
-      }
-      m_defines = idm->defines(file);
-
-    m_gotPathsFromManager = !dirs.isEmpty();
-    kDebug(9007) << "Got " << dirs.count() << " include-paths from build-manager";
-    foreach (const Path& dir, dirs) {
+    for (const auto& dir : idm->includes(file, IDefinesAndIncludesManager::Type(IDefinesAndIncludesManager::CompilerSpecific))){
       addInclude(dir);
     }
   }
 
-  if (noProject) {
-    for (const auto& dir : IDefinesAndIncludesManager::manager()->includes(nullptr)) {
+  if (m_noProject) {
+    for (const auto& dir : IDefinesAndIncludesManager::manager()->includes(m_source)) {
       addInclude( dir );
     }
-    m_defines = IDefinesAndIncludesManager::manager()->defines(nullptr);
-  } else if (!m_gotPathsFromManager) {
-    kDebug(9007) << "Did not find any include paths from project manager for" << m_source;
+    m_defines = IDefinesAndIncludesManager::manager()->defines(m_source);
   }
 }
 
@@ -139,39 +124,13 @@ void IncludePathComputer::computeBackground()
     return;
   }
 
-  if (!enableIncludePathResolution) {
-    m_ready = true;
-    return;
+  auto result = IDefinesAndIncludesManager::manager()->includesInBackground(m_source);
+
+  foreach (const auto& res, result) {
+    addInclude(res);
   }
 
-  if (m_effectiveBuildDirectory.isValid()) {
-    m_includeResolver.setOutOfSourceBuildSystem(m_projectDirectory.toLocalFile(), m_effectiveBuildDirectory.toLocalFile());
-  } else {
-    if (m_projectDirectory.isValid()) {
-      //Report that the build-manager did not return the build-directory, for debugging
-      kDebug(9007) << "Build manager for project %1 did not return a build directory" << m_projectName;
-    }
-    m_includeResolver.resetOutOfSourceBuild();
-  }
-
-  m_includePathDependency = m_includeResolver.findIncludePathDependency(m_source);
-  kDebug() << "current include path dependency state:" << m_includePathDependency.toString();
-
-  // only look at make when we did not get any paths from the build manager
-  m_includeResolver.enableMakeResolution(!m_gotPathsFromManager);
-  CppTools::PathResolutionResult result = m_includeResolver.resolveIncludePath(m_source);
-
-  m_includePathDependency = result.includePathDependency;
-  kDebug() << "new include path dependency:" << m_includePathDependency.toString();
-
-  foreach (const QString &res, result.paths) {
-    addInclude(Path(res));
-  }
-
-  if (!result) {
-    kDebug(9007) << "Failed to resolve include-path for \"" << m_source << "\":"
-                  << result.errorMessage << "\n" << result.longErrorMessage << "\n";
-
+  if (m_noProject) {
     // Last chance: Take a parsed version of the file from the du-chain, and get its include-paths
     // We will then get the include-path that some time was used to parse the file
     // NOTE: this is important for library headers, as when we open them they are not opened in any project
@@ -183,12 +142,11 @@ void IncludePathComputer::computeBackground()
         foreach(const IndexedString& path, envFile->includePaths()) {
           addInclude(Path(path.toUrl()));
         }
-        kDebug(9007) << "Took include-path for" << m_source << "from a random parsed duchain-version of it";
+        qCDebug(CPP) << "Took include-path for" << m_source << "from a random parsed duchain-version of it";
         break;
       }
     }
   }
-
   m_ready = true;
 }
 
