@@ -24,7 +24,6 @@
 #include <QString>
 #include <QStringList>
 
-#include <kdebug.h>
 #include <parser/rpp/chartools.h>
 #include <parser/rpp/macrorepository.h>
 
@@ -80,28 +79,28 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       m.formalsList().append(IndexedString("param"));
       insertMacro( macros, m );
     }
-    
+
     /// The following macros are required for qt only. That's why we set them to become active only when their
     /// 'real' versions become defined in qobjectdefs.h. A slight problem is that they are 'fixed', so they will block
     /// any other macros with the same names.
     {
       rpp::pp_macro m("Q_SLOTS");
       m.setDefinitionText( "__qt_slots__" );
-      
+
       m.defined = false;
       m.defineOnOverride = true;
       m.file = IndexedString("/qobjectdefs.h"); // Only define the macro if it is overriden in this file
       m.fixed = true;
-      
+
       insertMacro( macros, m );
 
       m.name = IndexedString("Q_PRIVATE_SLOT");
       m.formalsList().append(IndexedString("d"));
       m.formalsList().append(IndexedString("sig"));
       m.function_like = true;
-      m.setDefinitionText( "private slots: sig{ d; }; private:" );
+      m.setDefinitionText( "private __qt_slots__: sig{ d; }; private:" );
       insertMacro( macros, m );
-      
+
       m.name = IndexedString("slots");
       m.setDefinitionText("__qt_slots__");
       m.formalsList().clear();
@@ -122,7 +121,7 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       m.setDefinitionText("__qt_signal__");
       m.formalsList().clear();
       insertMacro( macros, m );
-      
+
       m.name = IndexedString("SLOT");
       m.setDefinitionText("__qt_slot__");
       m.formalsList().clear();
@@ -133,7 +132,7 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       m.formalsList().clear();
       insertMacro( macros, m );
     }
-    
+
     {
       // We don't provide a real implementation of offsetof, but at least provide a stub that allows correct use-building for the member.
       rpp::pp_macro m("__builtin_offsetof");
@@ -155,14 +154,6 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       insertMacro( macros, m );
     }
 
-    { // ignore C99 _Pragma
-      rpp::pp_macro m("_Pragma");
-      m.function_like = true;
-      m.formalsList().append(IndexedString("string_literal"));
-      m.setDefinitionText("");
-      insertMacro( macros, m );
-    }
-
     {
       // see: https://bugs.kde.org/show_bug.cgi?id=325882
       rpp::pp_macro m("__final");
