@@ -31,9 +31,9 @@ class MsvcCompiler : public ICompiler
 public:
     MsvcCompiler(const QString& name, const QString& path, bool editable, const QString& factoryName);
 
-    virtual QHash<QString, QString> defines() const override;
+    virtual KDevelop::Defines defines(const QString& arguments) const override;
 
-    virtual Path::List includes() const override;
+    virtual KDevelop::Path::List includes(const QString& arguments) const override;
 };
 
 #endif // MSVCCOMPILER_H
