@@ -55,7 +55,11 @@ const QString compilerNameKey = QLatin1String( "Name" );
 const QString compilerPathKey = QLatin1String( "Path" );
 const QString compilerTypeKey = QLatin1String( "Type" );
 
-QString parserArguments(){ return QStringLiteral("parserArguments"); }
+QString parserArguments()
+{
+    return QStringLiteral("parserArguments");
+}
+
 }
 
 // the grouplist is randomly sorted b/c it uses QSet internally
@@ -66,7 +70,10 @@ QStringList sorted(QStringList list)
     return list;
 }
 
-QString defaultArguments(){ return QStringLiteral("-ferror-limit=100 -fspell-checking -Wdocumentation -Wunused-parameter -Wunreachable-code -Wall -std=c++11"); }
+QString defaultArguments()
+{
+    return QStringLiteral("-ferror-limit=100 -fspell-checking -Wdocumentation -Wunused-parameter -Wunreachable-code -Wall -std=c++11");
+}
 
 CompilerPointer createCompilerFromConfig(KConfigGroup& cfg)
 {
@@ -135,6 +142,10 @@ QList<ConfigEntry> doReadSettings( KConfigGroup grp, bool remove = false )
         path.path = pathgrp.readEntry( ConfigConstants::projectPathKey, "" );
         path.parserArguments = pathgrp.readEntry(ConfigConstants::parserArguments(), defaultArguments());
 
+        if (path.parserArguments.isEmpty()) {
+            path.parserArguments = defaultArguments();
+        }
+
         { // defines
             // Backwards compatibility with old config style
             if(pathgrp.hasKey(ConfigConstants::definesKey)) {
@@ -187,6 +198,8 @@ QList<ConfigEntry> doReadSettings( KConfigGroup grp, bool remove = false )
         if ( remove ) {
             pathgrp.deleteGroup();
         }
+
+        Q_ASSERT(!path.parserArguments.isEmpty());
         paths << path;
     }
 
@@ -344,4 +357,5 @@ QString SettingsManager::defaultParserArguments() const
 ConfigEntry::ConfigEntry(const QString& path)
     : path(path)
     , compiler(SettingsManager::globalInstance()->provider()->checkCompilerExists({}))
+    , parserArguments(defaultArguments())
 {}
