@@ -18,9 +18,10 @@
 
 #include "defineswidget.h"
 
-#include <KAction>
+#include <KLocalizedString>
+#include <QAction>
 
-#include "ui_defineswidget.h"
+#include "../ui_defineswidget.h"
 #include "definesmodel.h"
 #include "debugarea.h"
 
@@ -32,18 +33,18 @@ DefinesWidget::DefinesWidget( QWidget* parent )
 {
     ui->setupUi( this );
     ui->defines->setModel( definesModel );
-    ui->defines->horizontalHeader()->setResizeMode( QHeaderView::Stretch );
-    connect( definesModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), SLOT(definesChanged()) );
-    connect( definesModel, SIGNAL(rowsInserted(QModelIndex,int,int)), SLOT(definesChanged()) );
-    connect( definesModel, SIGNAL(rowsRemoved(QModelIndex,int,int)), SLOT(definesChanged()) );
+    ui->defines->horizontalHeader()->setSectionResizeMode( QHeaderView::Stretch );
+    connect( definesModel, &DefinesModel::dataChanged, this, static_cast<void(DefinesWidget::*)()>(&DefinesWidget::definesChanged) );
+    connect( definesModel, &DefinesModel::rowsInserted, this, static_cast<void(DefinesWidget::*)()>(&DefinesWidget::definesChanged) );
+    connect( definesModel, &DefinesModel::rowsRemoved, this, static_cast<void(DefinesWidget::*)()>(&DefinesWidget::definesChanged) );
 
-    KAction* delDefAction = new KAction( i18n("Delete Define"), this );
-    delDefAction->setShortcut( KShortcut( "Del" ) );
+    QAction* delDefAction = new QAction( i18n("Delete Define"), this );
+    delDefAction->setShortcut( QKeySequence(Qt::Key_Delete) );
     delDefAction->setShortcutContext( Qt::WidgetWithChildrenShortcut );
-    delDefAction->setIcon( KIcon("list-remove") );
+    delDefAction->setIcon( QIcon::fromTheme("list-remove") );
     ui->defines->addAction( delDefAction );
     ui->defines->setContextMenuPolicy( Qt::ActionsContextMenu );
-    connect( delDefAction, SIGNAL(triggered()), SLOT(deleteDefine()) );
+    connect( delDefAction, &QAction::triggered, this, &DefinesWidget::deleteDefine );
 }
 
 void DefinesWidget::setDefines( const Defines& defines )
@@ -74,4 +75,3 @@ void DefinesWidget::deleteDefine()
     }
 }
 
-#include "defineswidget.moc"
