@@ -22,10 +22,8 @@
 #include <QWidget>
 
 #include <qabstractitemmodel.h>
-#include <language/interfaces/idefinesandincludesmanager.h>
+#include "idefinesandincludesmanager.h"
 
-class KFileDialog;
-class KUrlRequester;
 namespace Ui
 {
 class DefinesWidget;
