@@ -47,11 +47,11 @@ public:
     void setPaths( const QList< ConfigEntry >& paths );
     void addPath( const QUrl &url );
     QList<ConfigEntry> paths() const;
-    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
-    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
-    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
-    virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
-    virtual bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() ) override;
+    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
+    bool removeRows( int row, int count, const QModelIndex& parent = QModelIndex() ) override;
 private:
     QList<ConfigEntry> projectPaths;
     KDevelop::IProject* project;
