@@ -154,7 +154,7 @@ KJob* CMakeManager::createImportJob(ProjectFolderItem* item)
 
     // create the JSON file if it doesn't exist
     auto commandsFile = CMake::commandsFile(project);
-    if (!QFileInfo(commandsFile.toLocalFile()).exists()) {
+    if (!QFileInfo::exists(commandsFile.toLocalFile())) {
         qCDebug(CMAKE) << "couldn't find commands file:" << commandsFile << "- now trying to reconfigure";
         jobs << builder()->configure(project);
     }
@@ -269,7 +269,9 @@ static void populateTargets(ProjectFolderItem* folder, const QHash<KDevelop::Pat
     }
 
     foreach (const QString& name, dirTargets) {
-        if (!name.endsWith("_automoc"))
+        if (!name.endsWith("_automoc")
+            && name != QLatin1String("edit_cache")
+            && name != QLatin1String("rebuild_cache"))
             new CMakeTargetItem(folder, name);
     }
 
