@@ -25,8 +25,7 @@
 #include "cmakeprojectvisitor.h"
 #include "cmakelistsparser.h"
 #include <QString>
-#include <qtest_kde.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <cmakecondition.h>
@@ -35,21 +34,21 @@
 #include <tests/testcore.h>
 #include <astfactory.h>
 #include <cmakeprojectdata.h>
-#include <KTempDir>
-#include <KTemporaryFile>
+#include <QTemporaryDir>
+#include <QTemporaryFile>
 
-QTEST_KDEMAIN_CORE(CMakeProjectVisitorTest)
+QTEST_GUILESS_MAIN(CMakeProjectVisitorTest)
 
 using namespace KDevelop;
 
 #undef TRUE //krazy:exclude=captruefalse
 #undef FALSE //krazy:exclude=captruefalse
 
-static QSharedPointer<KTemporaryFile> prepareVisitoTestScript(const QString &scriptContent)
+static QSharedPointer<QTemporaryFile> prepareVisitoTestScript(const QString &scriptContent)
 {
-    QSharedPointer<KTemporaryFile> file(new KTemporaryFile);
+    QSharedPointer<QTemporaryFile> file(new QTemporaryFile);
     if ( !file->open() )
-        return QSharedPointer<KTemporaryFile>();
+        return QSharedPointer<QTemporaryFile>();
 
     QTextStream out(file.data());
     out << scriptContent;
@@ -531,7 +530,7 @@ void CMakeProjectVisitorTest::testRun()
     QFETCH(QList<StringPair>, cache);
     QFETCH(QList<StringPair>, results);
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(input);
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(input);
     QVERIFY(!file.isNull());
     CMakeFileContent code=CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
@@ -564,14 +563,22 @@ void CMakeProjectVisitorTest::testFinder_data()
 {
     QTest::addColumn<QString>("module");
     QTest::addColumn<QString>("args");
-    
-    QTest::newRow("ZLIB") << "ZLIB" << QString();
-    QTest::newRow("PNG") << "PNG" << QString();
+
+#if QT_VERSION >= 0x050000
+    QTest::newRow("Qt5") << "Qt5" << QString();
+    QTest::newRow("Qt5comp") << "Qt5" << QString("COMPONENTS Core Gui");
+    // TODO: Fails?
+    //QTest::newRow("KF5Parts") << "KF5Parts" << QString();
+#else
+    // most likely not installed when Qt5 is used
     QTest::newRow("Qt4") << "Qt4" << QString();
     QTest::newRow("Qt4comp") << "Qt4" << QString("COMPONENTS QtCore QtGui");
     QTest::newRow("KDE4") << "KDE4" << QString();
     QTest::newRow("Phonon") << "Phonon" << QString();
     QTest::newRow("Automoc4") << "Automoc4" << QString();
+#endif
+    QTest::newRow("ZLIB") << "ZLIB" << QString();
+    QTest::newRow("PNG") << "PNG" << QString();
     QTest::newRow("Boost") << "Boost" << QString("1.39");
     QTest::newRow("TestLib") << "TestLib" << QString();
     QTest::newRow("TestLib64") << "TestLib64" << QString();
@@ -598,7 +605,7 @@ void CMakeProjectVisitorTest::testFinder()
     QFETCH(QString, args);
     testFinder_init();
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(QString("find_package(%1 REQUIRED %2)\n").arg(module).arg(args));
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(QString("find_package(%1 REQUIRED %2)\n").arg(module).arg(args));
     QVERIFY(!file.isNull());
     CMakeFileContent code=CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
@@ -826,10 +833,10 @@ void CMakeProjectVisitorTest::testGlobs()
     QFETCH(QList<StringPair>, symlinks);
     QFETCH(QStringList, expectedFiles);
 
-    KTempDir dir;
+    QTemporaryDir dir;
     foreach(QString relativeFilePath, files)
     {
-        QString fileName = dir.name() + relativeFilePath;
+        QString fileName = dir.path() + '/' + relativeFilePath;
         QFile file(fileName);
         QDir fileDir(fileName.left(fileName.lastIndexOf('/')));
         if (!fileDir.exists())
@@ -841,14 +848,14 @@ void CMakeProjectVisitorTest::testGlobs()
     }
     foreach(StringPair pair, symlinks)
     {
-        QFile file(dir.name() + pair.first);
+        QFile file(dir.path() + '/' + pair.first);
         QVERIFY2(file.exists(),
             ("File doesn't exist: " + file.fileName()).toLatin1());
-        QVERIFY2(file.link(dir.name() + pair.second),
-            ("Failed to create a link: " + dir.name() + pair.second).toLatin1());
+        QVERIFY2(file.link(dir.path() + '/' + pair.second),
+            ("Failed to create a link: " + dir.path() + '/' + pair.second).toLatin1());
     }
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(input);
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(input);
     QVERIFY(!file.isNull());
     CMakeFileContent code = CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
@@ -857,7 +864,7 @@ void CMakeProjectVisitorTest::testGlobs()
     VariableMap vm;
     CacheValues val;
 
-    vm.insert("CMAKE_CURRENT_SOURCE_DIR", QStringList(dir.name()));
+    vm.insert("CMAKE_CURRENT_SOURCE_DIR", QStringList(dir.path()));
 
     CMakeProjectVisitor v(file->fileName(), fakeContext);
     v.setVariableMap(&vm);
@@ -868,7 +875,7 @@ void CMakeProjectVisitorTest::testGlobs()
     VariableMap::const_iterator it = v.variables()->constFind("RESULT");
     QVERIFY2(it != v.variables()->constEnd(), "RESULT variable doesn't exist");
     QStringList filesFound = it.value();
-    QDir baseDir(dir.name());
+    QDir baseDir(dir.path());
     for (int i = 0; i < filesFound.size(); i++)
     {
         QString file = filesFound[i];
@@ -969,7 +976,7 @@ void CMakeProjectVisitorTest::testTargetProperties()
     QFETCH(QString, target);
     QFETCH(QList<StringPair>, results);
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(input);
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(input);
     QVERIFY(!file.isNull());
     CMakeFileContent code=CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
@@ -1055,7 +1062,7 @@ void CMakeProjectVisitorTest::testBug335803()
     QFETCH(QString, input);
     QFETCH(QStringList, targetNames);
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(input);
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(input);
     QVERIFY(!file.isNull());
     CMakeFileContent code = CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
@@ -1107,7 +1114,7 @@ void CMakeProjectVisitorTest::testSetProperty()
     QFETCH(QString, name);
     QFETCH(QStringList, value);
 
-    QSharedPointer<KTemporaryFile> file = prepareVisitoTestScript(input);
+    QSharedPointer<QTemporaryFile> file = prepareVisitoTestScript(input);
     QVERIFY(!file.isNull());
     CMakeFileContent code = CMakeListsParser::readCMakeFile(file->fileName());
     QVERIFY(code.count() != 0);
