@@ -20,6 +20,7 @@
 #include "custombuildsystemconfigwidget.h"
 
 #include <KConfig>
+#include <KConfigGroup>
 
 #include "ui_custombuildsystemconfigwidget.h"
 #include "configconstants.h"
@@ -31,7 +32,7 @@ QString generateToolGroupName( CustomBuildSystemTool::ActionType type )
 {
     static const int toolTypeCount = CustomBuildSystemTool::Undefined + 1;
     // Static Qt-based objects are discouraged (MSVC-incompatible), so use raw strings
-    static const char* toolTypes[] = {
+    static const char* const toolTypes[] = {
         "Build",
         "Configure",
         "Install",
@@ -53,21 +54,21 @@ CustomBuildSystemConfigWidget::CustomBuildSystemConfigWidget( QWidget* parent )
 {
     ui->setupUi( this );
 
-    ui->addConfig->setIcon(KIcon( "list-add" ));
-    ui->removeConfig->setIcon(KIcon( "list-remove" ));
+    ui->addConfig->setIcon(QIcon::fromTheme( "list-add" ));
+    ui->removeConfig->setIcon(QIcon::fromTheme( "list-remove" ));
 
     // hack taken from kurlrequester, make the buttons a bit less in height so they better match the url-requester
     ui->addConfig->setFixedHeight( ui->currentConfig->sizeHint().height() );
     ui->removeConfig->setFixedHeight( ui->currentConfig->sizeHint().height() );
 
-    connect( ui->currentConfig, SIGNAL(activated(int)), SLOT(changeCurrentConfig(int)));
-    connect( ui->configWidget, SIGNAL(changed()), SLOT(configChanged()) );
+    connect( ui->currentConfig, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), this, &CustomBuildSystemConfigWidget::changeCurrentConfig);
+    connect( ui->configWidget, &ConfigWidget::changed, this, &CustomBuildSystemConfigWidget::configChanged );
 
-    connect( ui->addConfig, SIGNAL(clicked(bool)), SLOT(addConfig()));
-    connect( ui->removeConfig, SIGNAL(clicked(bool)), SLOT(removeConfig()));
-    connect( ui->currentConfig, SIGNAL(editTextChanged(QString)), SLOT(renameCurrentConfig(QString)) );
+    connect( ui->addConfig, &QPushButton::clicked, this, &CustomBuildSystemConfigWidget::addConfig);
+    connect( ui->removeConfig, &QPushButton::clicked, this, &CustomBuildSystemConfigWidget::removeConfig);
+    connect( ui->currentConfig, &QComboBox::editTextChanged, this, &CustomBuildSystemConfigWidget::renameCurrentConfig );
 
-    connect( this, SIGNAL(changed()), SLOT(verify()) );
+    connect( this, &CustomBuildSystemConfigWidget::changed, this, &CustomBuildSystemConfigWidget::verify );
 }
 
 void CustomBuildSystemConfigWidget::loadDefaults()
@@ -83,15 +84,15 @@ void CustomBuildSystemConfigWidget::loadFrom( KConfig* cfg )
         KConfigGroup subgrp = grp.group( grpName );
         CustomBuildSystemConfig config;
 
-        config.title = subgrp.readEntry( ConfigConstants::configTitleKey, "" );
-        config.buildDir = subgrp.readEntry( ConfigConstants::buildDirKey, "" );
+        config.title = subgrp.readEntry( ConfigConstants::configTitleKey, QString() );
+        config.buildDir = subgrp.readEntry( ConfigConstants::buildDirKey, QUrl() );
 
         foreach( const QString& subgrpName, subgrp.groupList() ) {
             if( subgrpName.startsWith( ConfigConstants::toolGroupPrefix ) ) {
                 KConfigGroup toolgrp = subgrp.group( subgrpName );
                 CustomBuildSystemTool tool;
                 tool.arguments = toolgrp.readEntry( ConfigConstants::toolArguments, "" );
-                tool.executable = toolgrp.readEntry( ConfigConstants::toolExecutable, KUrl() );
+                tool.executable = toolgrp.readEntry( ConfigConstants::toolExecutable, QUrl() );
                 tool.envGrp = toolgrp.readEntry( ConfigConstants::toolEnvironment, QString() );
                 tool.enabled = toolgrp.readEntry( ConfigConstants::toolEnabled, false );
                 tool.type = CustomBuildSystemTool::ActionType( toolgrp.readEntry( ConfigConstants::toolType, 0 ) );
@@ -121,13 +122,13 @@ void CustomBuildSystemConfigWidget::saveConfig( KConfigGroup& grp, CustomBuildSy
         grp.writeEntry( ConfigConstants::currentConfigKey, subgrp.name() );
 
     subgrp.writeEntry( ConfigConstants::configTitleKey, c.title );
-    subgrp.writeEntry( ConfigConstants::buildDirKey, c.buildDir );
+    subgrp.writeEntry<QUrl>( ConfigConstants::buildDirKey, c.buildDir );
     foreach( const CustomBuildSystemTool& tool, c.tools ) {
         KConfigGroup toolgrp = subgrp.group( generateToolGroupName( tool.type ) );
         toolgrp.writeEntry( ConfigConstants::toolType, int(tool.type) );
         toolgrp.writeEntry( ConfigConstants::toolEnvironment , tool.envGrp );
         toolgrp.writeEntry( ConfigConstants::toolEnabled, tool.enabled );
-        toolgrp.writeEntry( ConfigConstants::toolExecutable, tool.executable );
+        toolgrp.writeEntry<QUrl>( ConfigConstants::toolExecutable, tool.executable );
         toolgrp.writeEntry( ConfigConstants::toolArguments, tool.arguments );
     }
 }
@@ -213,5 +214,4 @@ void CustomBuildSystemConfigWidget::renameCurrentConfig(const QString& name) {
 }
 
 
-#include "custombuildsystemconfigwidget.moc"
 
