@@ -12,31 +12,18 @@
 #define CUSTOMMAKEMODELITEMS_H
 
 #include <project/projectmodel.h>
-namespace KDevelop
-{
-class IProject;
-}
-
-template<typename T1,typename T2> struct QPair;
-// template<typename T1,typename T2> class QHash;
-#include <QHash>
-#include <KUrl>
-template<typename T1> class QList;
-class QString;
-class CustomMakeTreeSynchronizer;
-class CustomMakeManager;
 
 class CustomMakeTargetItem : public KDevelop::ProjectTargetItem
 {
 public:
     CustomMakeTargetItem( KDevelop::IProject *project, const QString &name, ProjectBaseItem*parent=NULL );
 
-    virtual KUrl::List includeDirectories() const;
+    virtual QList<QUrl> includeDirectories() const;
     virtual QHash<QString, QString> environment() const;
     virtual QList<QPair<QString, QString> > defines() const;
 
 private:
-    KUrl::List m_includeDirs;
+    QList<QUrl> m_includeDirs;
     QHash<QString, QString> m_envs;
     QList<QPair <QString, QString> > m_defines;
 
