@@ -23,17 +23,15 @@
 #ifndef OKTETADOCUMENT_H
 #define OKTETADOCUMENT_H
 
-// Plugin
-#include "oktetaglobal.h"
 // Kasten core
-#include <kastencore.h>
+#include <kasten/kastencore.h>
 // KDevPlatform
 #include <sublime/urldocument.h>
 #include <interfaces/idocument.h>
 //Qt
 #include <QtCore/QList>
 
-namespace KASTEN_NAMESPACE {
+namespace Kasten {
 class ByteArrayDocument;
 class AbstractDocument;
 }
@@ -85,13 +83,7 @@ class OktetaDocument : public Sublime::UrlDocument, public IDocument
   protected Q_SLOTS:
     void onByteArrayDocumentChanged();
     // Moc is too primitive to know about namespace aliase
-#if KASTEN_VERSION == 2
-    void onByteArrayDocumentLoaded( Kasten2::AbstractDocument* document );
-#elif KASTEN_VERSION == 1
-    void onByteArrayDocumentLoaded( Kasten1::AbstractDocument* document );
-#else
     void onByteArrayDocumentLoaded( Kasten::AbstractDocument* document );
-#endif
 
   private:
     OktetaPlugin* mPlugin;
